import * as i0 from '@angular/core';
import { Pipe, Component, ViewEncapsulation, Input, NgModule, Injectable, EventEmitter, Directive, Output, HostBinding, HostListener, forwardRef, Self, NgZone, ErrorHandler, Optional, SkipSelf } from '@angular/core';
import * as i1 from 'monkey-style-guide';
import { MonkeyButtonModule, MonkeyIconModule, MonkeyInputModule, MonkeyModalModule, MonkeyUtils, MonkeyStyleGuideModule, MonkeyStyleGuideModalService, MonkeyStyleGuideSettingsService, MonkeyStyleGuideSnackbarService } from 'monkey-style-guide';
import * as i1$1 from '@ngx-translate/core';
import { TranslateService, TranslateModule } from '@ngx-translate/core';
import * as moment_ from 'moment';
import * as i1$2 from '@angular/common';
import { formatNumber, CurrencyPipe, CommonModule, registerLocaleData } from '@angular/common';
import * as i1$3 from '@angular/router';
import { NavigationStart, NavigationEnd, NavigationError, NavigationCancel } from '@angular/router';
import { BehaviorSubject, throwError, interval, concat, of, Subject } from 'rxjs';
import { filter, take, takeWhile, map, catchError, first, takeUntil, mergeMap, finalize } from 'rxjs/operators';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { __decorate } from 'tslib';
import * as i1$4 from '@angular/common/http';
import { HttpParams, HttpErrorResponse, HTTP_INTERCEPTORS, HttpClientModule } from '@angular/common/http';
import localePTBR from '@angular/common/locales/global/pt';
import * as i1$5 from 'ngx-cookie-service';
import { datadogRum } from '@datadog/browser-rum';
import * as i1$6 from '@angular/service-worker';
import { ServiceWorkerModule } from '@angular/service-worker';
import { initialize } from 'launchdarkly-js-client-sdk';

/* eslint-disable comma-dangle */
/* eslint-disable max-len */
/* eslint-disable no-useless-escape */
/* eslint-disable no-plusplus */
/* eslint-disable no-cond-assign */
/* eslint-disable eqeqeq */
/* eslint-disable no-redeclare */
/* eslint-disable vars-on-top */
/* eslint-disable no-var */
/* eslint-disable block-scoped-var */
class MonkeyEcxUtils {
    static persistNullEmptyUndefined(tp) {
        return tp !== null && tp !== undefined && tp !== '';
    }
    static getDocumentType(doc, country) {
        if (!doc)
            return '';
        if (country === 'cl')
            return 'RUT';
        return doc.length <= 11 ? 'CPF' : 'CNPJ';
    }
    static getDocumentMask(type) {
        if (type === 'CPF')
            return '000.000.000-00';
        return '00.000.000/0000-00';
    }
    static formatDocumentWithMask(doc, withType, country) {
        if (!doc)
            return doc;
        let formated = '';
        if (country === 'cl') {
            formated = doc.replace(/^(\d{1,2})(\d{3})(\d{3})(\w{1})$/, '$1.$2.$3-$4');
            return `${formated}`;
        }
        if (doc.length === 14) {
            formated = doc
                .replace(/^(\d{2})(\d)/, '$1.$2')
                .replace(/^(\d{2})\.(\d{3})(\d)/, '$1.$2.$3')
                .replace(/\.(\d{3})(\d)/, '.$1/$2')
                .replace(/(\d{4})(\d)/, '$1-$2');
        }
        else {
            formated = doc
                .replace(/^(\d{3})(\d)/, '$1.$2')
                .replace(/^(\d{3})\.(\d{3})(\d)/, '$1.$2.$3')
                .replace(/\.(\d{3})(\d)/, '.$1-$2');
        }
        return `${withType ? `${this.getDocumentType(doc)}:` : ''} ${formated}`;
    }
    static cutFirstLastName(value, tp = 'first') {
        var _a, _b;
        const split = (_a = value === null || value === void 0 ? void 0 : value.trim()) === null || _a === void 0 ? void 0 : _a.split(' ');
        if (tp === 'first')
            return split[0];
        return (_b = split === null || split === void 0 ? void 0 : split.splice(1, split.length)) === null || _b === void 0 ? void 0 : _b.join(' ');
    }
    static isCPFCNPJValid(document) {
        document = document.replace(/[^\d]/g, '');
        if (document.length === 11) {
            let base = [10, 9, 8, 7, 6, 5, 4, 3, 2, 1, 0];
            for (var i = 0, n = 0; i < 9; n += document[i] * base[i++])
                ;
            if (document[9] != ((n %= 11) <= 1 ? 0 : 11 - n)) {
                return false;
            }
            base = [11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1, 0];
            for (var i = 0, n = 0; i <= 9; n += document[i] * base[i++])
                ;
            if (document[10] != ((n %= 11) <= 1 ? 0 : 11 - n)) {
                return false;
            }
            return true;
        }
        if (document.length === 14 || /0{14}/.test(document)) {
            const base = [6, 5, 4, 3, 2, 9, 8, 7, 6, 5, 4, 3, 2];
            for (var i = 0, n = 0; i < 12; n += document[i] * base[++i])
                ;
            if (document[12] != ((n %= 11) < 2 ? 0 : 11 - n)) {
                return false;
            }
            for (var i = 0, n = 0; i <= 12; n += document[i] * base[i++])
                ;
            if (document[13] != ((n %= 11) < 2 ? 0 : 11 - n)) {
                return false;
            }
            return true;
        }
        return false;
    }
    static isValidRUT(document) {
        if (!document || document.trim().length < 3)
            return false;
        const documentHandled = document.replace(/[^0-9kK]/g, '');
        if (documentHandled.length < 3)
            return false;
        const calcDv = (rut) => {
            const value = `${rut}`;
            let sum = 0;
            let mult = 2;
            for (let i = 1; i <= value.length; i++) {
                const index = mult * Number(value.charAt(value.length - i));
                sum += index;
                if (mult < 7) {
                    mult += 1;
                }
                else {
                    mult = 2;
                }
            }
            const dvEsperado = 11 - (sum % 11);
            if (dvEsperado === 10)
                return 'K';
            if (dvEsperado === 11)
                return '0';
            return `${dvEsperado}`;
        };
        const num = documentHandled.slice(0, -1);
        const dgv = documentHandled.slice(-1).toUpperCase();
        const dvCalc = calcDv(num);
        return dvCalc === dgv;
    }
    static isValidUrl(txt) {
        const regex = new RegExp(/^(http:\/\/www\.|https:\/\/www\.|http:\/\/|https:\/\/)+[a-z0-9]+([\-\.]{1}[a-z0-9]+)*\.[a-z]{2,10}(:[0-9]{1,5})?(\/.*)?$/gm);
        return regex.test(txt);
    }
    static isValidZipCode(zipCode) {
        return `${this.handleOnlyNumbers(zipCode)}`.length === 8;
    }
    static getRandomString(len, charSet) {
        charSet = charSet || 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';
        const randomString = new Array(len)
            .fill('1')
            .map(() => {
            return charSet.charAt(Math.floor(Math.random() * charSet.length));
        })
            .join('');
        return randomString;
    }
    static handleOnlyNumbers(value) {
        if (!value)
            return null;
        return value.replace(new RegExp(/[^0-9]/g), '');
    }
    static handleOnlyAlphaNumeric(value) {
        if (!value)
            return '';
        return value.replace(new RegExp(/[^0-9A-Za-z]/, 'g'), '');
    }
    static capitalize(value) {
        return `${value.charAt(0).toUpperCase()}${value.slice(1)}`;
    }
    static formatZipCode(zipCode) {
        if (!zipCode)
            return zipCode;
        const formated = zipCode
            .replace(/^(\d{5})(\d)/, '$1-$2')
            .replace(/\.(\d{3})(\d)/, '.$1-$2');
        return `${formated}`;
    }
    static formatFileSize(size) {
        const units = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
        let l = 0;
        while (size >= 1024 && ++l) {
            size /= 1024;
        }
        return `${size.toFixed(size < 10 && l > 0 ? 1 : 0)} ${units[l]}`;
    }
    static sufflue(data) {
        for (let i = data.length - 1; i > 0; i--) {
            const j = Math.floor(Math.random() * i);
            const temp = data[i];
            data[i] = data[j];
            data[j] = temp;
        }
        return data;
    }
    static handleBlobFile(theBlob, fileName, fileType) {
        function blobToFile(theBlob, fileName) {
            const b = theBlob;
            b.lastModifiedDate = new Date();
            b.name = fileName;
            return b;
        }
        let file;
        if (!navigator.msSaveBlob) {
            file = new File([theBlob], fileName, {
                type: fileType,
            });
        }
        else {
            file = new Blob([theBlob], {
                type: fileType,
            });
            file = blobToFile(file, fileName);
        }
        return file;
    }
    static truncate(text, maxLength = 25) {
        const midChar = '...';
        if (!text)
            return midChar;
        if (text && text.length <= maxLength)
            return text;
        const left = Math.ceil(maxLength / 2);
        const right = text.length - left + 1;
        return `${text.substr(0, left)} ${midChar} ${text.substring(right)}`;
    }
    static isLocalhost() {
        const { href } = window === null || window === void 0 ? void 0 : window.location;
        if (!href)
            return false;
        return (href === null || href === void 0 ? void 0 : href.search('localhost')) >= 0;
    }
    static isSameOrigin(frontend) {
        const initialPath = window.location.origin;
        return (initialPath || '') === frontend;
    }
}

const moment$2 = moment_;
class MonkeyEcxFormatDateTimelapsePipe {
    constructor() {
        // not todo
    }
    transform(date, showTime = false, useUtc = true, format) {
        var _a;
        if (!MonkeyEcxUtils.persistNullEmptyUndefined(date))
            return '';
        if (!format) {
            format = '- HH:mm';
        }
        let stillUtc = moment$2.utc(date).toDate();
        if (!useUtc)
            stillUtc = moment$2(date).toDate();
        if (((_a = date.toString()) === null || _a === void 0 ? void 0 : _a.indexOf(':')) <= -1) {
            stillUtc = date;
            showTime = false;
        }
        const formatFrom = `YYYY/MM/DD${showTime ? ` ${format}` : ''}`;
        const formatTo = `DD/MM/YYYY${showTime ? ` ${format}` : ''}`;
        return `${moment$2(stillUtc, formatFrom).format(formatTo)}`;
    }
}
MonkeyEcxFormatDateTimelapsePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatDateTimelapsePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
MonkeyEcxFormatDateTimelapsePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatDateTimelapsePipe, name: "monkeyecxFormatDateTimelapse" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatDateTimelapsePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'monkeyecxFormatDateTimelapse'
                }]
        }], ctorParameters: function () { return []; } });

class ClosedToMaintenanceComponent {
    constructor() {
        this._configBoostrap = null;
    }
    ngOnInit() {
        this._configBoostrap = this.config.data;
    }
    onClose() {
        document.location.reload();
    }
}
ClosedToMaintenanceComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: ClosedToMaintenanceComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ClosedToMaintenanceComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.15", type: ClosedToMaintenanceComponent, selector: "monkeyecx-closed-to-maintenance", inputs: { config: "config", modalRef: "modalRef" }, ngImport: i0, template: "<monkey-modal [config]=\"config\" [modalRef]=\"modalRef\">\r\n  <div class=\"d-flex flex-column justify-content-center align-items-center\">\r\n    <span class=\"h2\">\r\n      {{ 'SCREENS.CLOSED-TO-MAINTENANCE.TITLE' | translate }}\r\n    </span>\r\n    <span class=\"information-title mt-4\">\r\n      {{ 'SCREENS.CLOSED-TO-MAINTENANCE.INFORMATION-1' | translate }}\r\n    </span>\r\n    <span class=\"information-title mt-4\">\r\n      {{ 'SCREENS.CLOSED-TO-MAINTENANCE.INFORMATION-2' | translate }}\r\n    </span>\r\n    <span class=\"information mt-3\">\r\n      {{ 'SCREENS.CLOSED-TO-MAINTENANCE.INFORMATION-3' | translate }}\r\n      {{ _configBoostrap?.maintenance?.endDate | monkeyecxFormatDateTimelapse: true }}\r\n    </span>\r\n    <span class=\"information-title mt-4\">\r\n      {{ 'SCREENS.CLOSED-TO-MAINTENANCE.INFORMATION-4' | translate }}\r\n    </span>\r\n  </div>\r\n  <div class=\"d-flex flex-column justify-content-center align-items-center mt-5\">\r\n    <monkey-button type=\"primary\" color=\"theme\" (click)=\"onClose()\">\r\n      {{ 'SCREENS.CLOSED-TO-MAINTENANCE.BUTTONS.UPDATE-MAINTENANCE' | translate }}\r\n    </monkey-button>\r\n  </div>\r\n</monkey-modal>", styles: ["monkeyecx-closed-to-maintenance .body{padding:24px;width:100%}monkeyecx-closed-to-maintenance .information-title{font-style:normal;font-weight:600;font-size:25px;line-height:32px;display:flex;align-items:center;text-align:center;color:#4b4a53}monkeyecx-closed-to-maintenance .information{font-style:normal;font-weight:normal;font-size:20px;line-height:24px;display:flex;align-items:center;text-align:center;color:#4b4a53;max-width:600px}monkeyecx-closed-to-maintenance .browser-name{font-style:normal;font-weight:normal;font-size:16px;line-height:24px;text-align:center;color:#9c9ca6}monkeyecx-closed-to-maintenance .option{text-decoration:none;padding:4px;background:#eee;border:1px solid #d6d6d6;box-sizing:border-box;border-radius:16px}monkeyecx-closed-to-maintenance monkey-modal mecx-monkey-modal .body{margin-bottom:0!important}\n"], components: [{ type: i1.MonkeyModalComponent, selector: "monkey-modal", inputs: ["config", "modalRef", "onHandleConfirm"] }, { type: i1.MonkeyButtonComponent, selector: "monkey-button", inputs: ["label", "icon", "iconPosition", "type", "color", "disabled", "size"] }], pipes: { "translate": i1$1.TranslatePipe, "monkeyecxFormatDateTimelapse": MonkeyEcxFormatDateTimelapsePipe }, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: ClosedToMaintenanceComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'monkeyecx-closed-to-maintenance',
                    templateUrl: './closed-to-maintenance.component.html',
                    styleUrls: ['./closed-to-maintenance.component.scss'],
                    encapsulation: ViewEncapsulation.None
                }]
        }], propDecorators: { config: [{
                type: Input
            }], modalRef: [{
                type: Input
            }] } });

class MonkeyEcxFormatNumber {
    constructor() {
        // not to do
    }
    transform(number) {
        if (!MonkeyEcxUtils.persistNullEmptyUndefined(number))
            return '';
        return formatNumber(Number(number), 'ptbr');
    }
}
MonkeyEcxFormatNumber.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatNumber, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
MonkeyEcxFormatNumber.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatNumber, name: "monkeyecxFormatNumber" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatNumber, decorators: [{
            type: Pipe,
            args: [{
                    name: 'monkeyecxFormatNumber'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxFormatValue {
    constructor() {
        // not to do
    }
    transform(number) {
        if (!MonkeyEcxUtils.persistNullEmptyUndefined(number))
            return '';
        return number;
    }
}
MonkeyEcxFormatValue.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatValue, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
MonkeyEcxFormatValue.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatValue, name: "monkeyecxFormatValue" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatValue, decorators: [{
            type: Pipe,
            args: [{
                    name: 'monkeyecxFormatValue'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxFormatDocumentPipe {
    constructor() {
        // not to do
    }
    transform(document, withType) {
        if (!MonkeyEcxUtils.persistNullEmptyUndefined(document))
            return '';
        return MonkeyEcxUtils.formatDocumentWithMask(document, withType);
    }
}
MonkeyEcxFormatDocumentPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatDocumentPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
MonkeyEcxFormatDocumentPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatDocumentPipe, name: "monkeyecxFormatDocument" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatDocumentPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'monkeyecxFormatDocument'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxDisplayFirstNamePipe {
    constructor() {
        // not to do
    }
    transform(name) {
        if (!MonkeyEcxUtils.persistNullEmptyUndefined(name))
            return '';
        return MonkeyEcxUtils.cutFirstLastName(name);
    }
}
MonkeyEcxDisplayFirstNamePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDisplayFirstNamePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
MonkeyEcxDisplayFirstNamePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDisplayFirstNamePipe, name: "monkeyecxDisplayFirstName" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDisplayFirstNamePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'monkeyecxDisplayFirstName'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxFormatSizePipe {
    constructor() {
        // not to do
    }
    transform(size) {
        if (!size)
            return '0 B';
        const sizeNum = Number(size);
        return MonkeyEcxUtils.formatFileSize(sizeNum);
    }
}
MonkeyEcxFormatSizePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatSizePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
MonkeyEcxFormatSizePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatSizePipe, name: "monkeyecxFormatSize" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatSizePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'monkeyecxFormatSize'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxFormatCurrencyPipe {
    constructor(injector, currencyPipe) {
        this.injector = injector;
        this.currencyPipe = currencyPipe;
        this.currencyCode = 'BRL';
        this.currentLocale = 'pt-BR';
        const translateService = this.injector.get(TranslateService);
        translateService.get('MONKEY-CURRENCY-CODE').subscribe((_) => {
            this.currencyCode = _;
            this.currentLocale = translateService.getDefaultLang();
        });
    }
    transform(value) {
        const { currencyCode, currentLocale } = this;
        return this.currencyPipe.transform(value, currencyCode, 'symbol', '', currentLocale);
    }
}
MonkeyEcxFormatCurrencyPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatCurrencyPipe, deps: [{ token: i0.Injector }, { token: i1$2.CurrencyPipe }], target: i0.ɵɵFactoryTarget.Pipe });
MonkeyEcxFormatCurrencyPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatCurrencyPipe, name: "monkeyecxFormatCurrency" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatCurrencyPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'monkeyecxFormatCurrency'
                }]
        }], ctorParameters: function () { return [{ type: i0.Injector }, { type: i1$2.CurrencyPipe }]; } });

class MonkeyEcxFormatZipCodePipe {
    constructor() {
        // not to do
    }
    transform(zipCode) {
        if (!MonkeyEcxUtils.persistNullEmptyUndefined(zipCode))
            return '';
        return MonkeyEcxUtils.formatZipCode(zipCode);
    }
}
MonkeyEcxFormatZipCodePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatZipCodePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
MonkeyEcxFormatZipCodePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatZipCodePipe, name: "monkeyecxFormatZipCode" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatZipCodePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'monkeyecxFormatZipCode'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxTextTruncatePipe {
    constructor() {
        // not to do
    }
    transform(text, maxLength = 25) {
        const midChar = '...';
        if (!text)
            return midChar;
        if (text && text.length <= maxLength)
            return text;
        const left = Math.ceil(maxLength / 2);
        const right = text.length - left + 1;
        return `${text.substr(0, left)} ${midChar} ${text.substring(right)}`;
    }
}
MonkeyEcxTextTruncatePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxTextTruncatePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
MonkeyEcxTextTruncatePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxTextTruncatePipe, name: "monkeyecxTextTruncate" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxTextTruncatePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'monkeyecxTextTruncate'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxDocumentTypePipe {
    constructor() {
        // not to do
    }
    transform(document) {
        if (!MonkeyEcxUtils.persistNullEmptyUndefined(document))
            return '';
        return MonkeyEcxUtils.getDocumentType(document);
    }
}
MonkeyEcxDocumentTypePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDocumentTypePipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
MonkeyEcxDocumentTypePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDocumentTypePipe, name: "monkeyecxDocumentType" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDocumentTypePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'monkeyecxDocumentType'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxTruncateQtdPipe {
    transform(number, threshold) {
        return `${number > threshold ? `${threshold}+` : number}`;
    }
}
MonkeyEcxTruncateQtdPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxTruncateQtdPipe, deps: [], target: i0.ɵɵFactoryTarget.Pipe });
MonkeyEcxTruncateQtdPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxTruncateQtdPipe, name: "monkeyecxTruncateQtd" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxTruncateQtdPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'monkeyecxTruncateQtd'
                }]
        }] });

class MonkeyEcxPipesModule {
}
MonkeyEcxPipesModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxPipesModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MonkeyEcxPipesModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxPipesModule, declarations: [MonkeyEcxFormatDocumentPipe,
        MonkeyEcxFormatDateTimelapsePipe,
        MonkeyEcxDisplayFirstNamePipe,
        MonkeyEcxFormatSizePipe,
        MonkeyEcxFormatCurrencyPipe,
        MonkeyEcxFormatZipCodePipe,
        MonkeyEcxFormatNumber,
        MonkeyEcxFormatValue,
        MonkeyEcxTextTruncatePipe,
        MonkeyEcxTruncateQtdPipe,
        MonkeyEcxDocumentTypePipe], exports: [MonkeyEcxFormatDocumentPipe,
        MonkeyEcxFormatDateTimelapsePipe,
        MonkeyEcxDisplayFirstNamePipe,
        MonkeyEcxFormatSizePipe,
        MonkeyEcxFormatCurrencyPipe,
        MonkeyEcxFormatZipCodePipe,
        MonkeyEcxFormatNumber,
        MonkeyEcxFormatValue,
        MonkeyEcxTextTruncatePipe,
        MonkeyEcxTruncateQtdPipe,
        MonkeyEcxDocumentTypePipe] });
MonkeyEcxPipesModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxPipesModule, providers: [CurrencyPipe] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxPipesModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        MonkeyEcxFormatDocumentPipe,
                        MonkeyEcxFormatDateTimelapsePipe,
                        MonkeyEcxDisplayFirstNamePipe,
                        MonkeyEcxFormatSizePipe,
                        MonkeyEcxFormatCurrencyPipe,
                        MonkeyEcxFormatZipCodePipe,
                        MonkeyEcxFormatNumber,
                        MonkeyEcxFormatValue,
                        MonkeyEcxTextTruncatePipe,
                        MonkeyEcxTruncateQtdPipe,
                        MonkeyEcxDocumentTypePipe
                    ],
                    exports: [
                        MonkeyEcxFormatDocumentPipe,
                        MonkeyEcxFormatDateTimelapsePipe,
                        MonkeyEcxDisplayFirstNamePipe,
                        MonkeyEcxFormatSizePipe,
                        MonkeyEcxFormatCurrencyPipe,
                        MonkeyEcxFormatZipCodePipe,
                        MonkeyEcxFormatNumber,
                        MonkeyEcxFormatValue,
                        MonkeyEcxTextTruncatePipe,
                        MonkeyEcxTruncateQtdPipe,
                        MonkeyEcxDocumentTypePipe
                    ],
                    providers: [CurrencyPipe]
                }]
        }] });

class ClosedToMaintenanceModule {
}
ClosedToMaintenanceModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: ClosedToMaintenanceModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
ClosedToMaintenanceModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: ClosedToMaintenanceModule, declarations: [ClosedToMaintenanceComponent], imports: [CommonModule,
        MonkeyButtonModule,
        MonkeyIconModule,
        MonkeyInputModule,
        MonkeyModalModule,
        MonkeyEcxPipesModule, i1$1.TranslateModule], exports: [ClosedToMaintenanceComponent] });
ClosedToMaintenanceModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: ClosedToMaintenanceModule, imports: [[
            CommonModule,
            MonkeyButtonModule,
            MonkeyIconModule,
            MonkeyInputModule,
            MonkeyModalModule,
            MonkeyEcxPipesModule,
            TranslateModule.forChild()
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: ClosedToMaintenanceModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [ClosedToMaintenanceComponent],
                    imports: [
                        CommonModule,
                        MonkeyButtonModule,
                        MonkeyIconModule,
                        MonkeyInputModule,
                        MonkeyModalModule,
                        MonkeyEcxPipesModule,
                        TranslateModule.forChild()
                    ],
                    exports: [ClosedToMaintenanceComponent]
                }]
        }] });

class MonkeyEcxProgressBarService {
    constructor(router) {
        this.router = router;
        this.init();
    }
    init() {
        this.visible = new BehaviorSubject(false);
        this.router.events
            .pipe(filter((event) => {
            return event instanceof NavigationStart;
        }))
            .subscribe(() => {
            this.show();
        });
        this.router.events
            .pipe(filter((event) => {
            return (event instanceof NavigationEnd ||
                event instanceof NavigationError ||
                event instanceof NavigationCancel);
        }))
            .subscribe(() => {
            this.hide();
        });
    }
    show() {
        this.visible.next(true);
    }
    hide() {
        this.visible.next(false);
    }
    visibleConfig() {
        return this.visible.asObservable();
    }
}
MonkeyEcxProgressBarService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxProgressBarService, deps: [{ token: i1$3.Router }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxProgressBarService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxProgressBarService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxProgressBarService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1$3.Router }]; } });

class MonkeyEcxProgressBarComponent {
    constructor(progressBarService) {
        this.progressBarService = progressBarService;
        this.visible = false;
        //not to do
    }
    ngOnInit() {
        this.progressBarService.visibleConfig().subscribe((visible) => {
            this.visible = visible;
        });
    }
}
MonkeyEcxProgressBarComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxProgressBarComponent, deps: [{ token: MonkeyEcxProgressBarService }], target: i0.ɵɵFactoryTarget.Component });
MonkeyEcxProgressBarComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.15", type: MonkeyEcxProgressBarComponent, selector: "monkeyecx-progress-bar", ngImport: i0, template: "<ng-container *ngIf=\"visible\">\r\n  <progress class=\"monkey-progress monkey-progress__theme\"></progress>\r\n</ng-container>\r\n", styles: ["monkeyecx-progress-bar{position:absolute;width:100%;margin-top:-9.5px;z-index:99998}\n"], directives: [{ type: i1$2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }], encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxProgressBarComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'monkeyecx-progress-bar',
                    templateUrl: './progress-bar.component.html',
                    styleUrls: ['./progress-bar.component.scss'],
                    encapsulation: ViewEncapsulation.None
                }]
        }], ctorParameters: function () { return [{ type: MonkeyEcxProgressBarService }]; } });

class MonkeyEcxProgressBarModule {
}
MonkeyEcxProgressBarModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxProgressBarModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MonkeyEcxProgressBarModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxProgressBarModule, declarations: [MonkeyEcxProgressBarComponent], imports: [CommonModule], exports: [MonkeyEcxProgressBarComponent] });
MonkeyEcxProgressBarModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxProgressBarModule, imports: [[CommonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxProgressBarModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [MonkeyEcxProgressBarComponent],
                    imports: [CommonModule],
                    exports: [MonkeyEcxProgressBarComponent]
                }]
        }] });

class VersionChangedComponent {
    onClose() {
        document.location.reload();
    }
}
VersionChangedComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: VersionChangedComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
VersionChangedComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.15", type: VersionChangedComponent, selector: "monkeyecx-version-changed", inputs: { config: "config", modalRef: "modalRef" }, ngImport: i0, template: "<monkey-modal [config]=\"config\" [modalRef]=\"modalRef\">\r\n  <div class=\"d-flex flex-column justify-content-center align-items-center\">\r\n    <span class=\"h2\">\r\n      {{ 'SCREENS.VERSION-CHANGED.TITLE' | translate }}\r\n    </span>\r\n    <span class=\"information-title mt-4\">\r\n      {{ 'SCREENS.VERSION-CHANGED.INFORMATION-1' | translate }}\r\n    </span>\r\n    <span class=\"information mt-3\">\r\n      {{ 'SCREENS.VERSION-CHANGED.INFORMATION-2' | translate }}\r\n    </span>\r\n  </div>\r\n  <div class=\"d-flex flex-column justify-content-center align-items-center mt-5\">\r\n    <monkey-button type=\"primary\" color=\"theme\" (click)=\"onClose()\">\r\n      {{ 'SCREENS.VERSION-CHANGED.BUTTONS.UPDATE-VERSION' | translate }}\r\n    </monkey-button>\r\n  </div>\r\n</monkey-modal>", styles: ["monkeyecx-version-changed .body{padding:24px;width:100%}monkeyecx-version-changed .information-title{font-style:normal;font-weight:600;font-size:25px;line-height:32px;display:flex;align-items:center;text-align:center;color:#4b4a53;max-width:600px}monkeyecx-version-changed .information{font-style:normal;font-weight:normal;font-size:20px;line-height:24px;display:flex;align-items:center;text-align:center;color:#4b4a53;max-width:600px}monkeyecx-version-changed .browser-name{font-style:normal;font-weight:normal;font-size:16px;line-height:24px;text-align:center;color:#9c9ca6}monkeyecx-version-changed .option{text-decoration:none;padding:4px;background:#eee;border:1px solid #d6d6d6;box-sizing:border-box;border-radius:16px}monkeyecx-version-changed monkey-modal mecx-monkey-modal .body{margin-bottom:0!important}\n"], components: [{ type: i1.MonkeyModalComponent, selector: "monkey-modal", inputs: ["config", "modalRef", "onHandleConfirm"] }, { type: i1.MonkeyButtonComponent, selector: "monkey-button", inputs: ["label", "icon", "iconPosition", "type", "color", "disabled", "size"] }], pipes: { "translate": i1$1.TranslatePipe }, encapsulation: i0.ViewEncapsulation.None });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: VersionChangedComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'monkeyecx-version-changed',
                    templateUrl: './version-changed.component.html',
                    styleUrls: ['./version-changed.component.scss'],
                    encapsulation: ViewEncapsulation.None
                }]
        }], propDecorators: { config: [{
                type: Input
            }], modalRef: [{
                type: Input
            }] } });

class VersionChangedModule {
}
VersionChangedModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: VersionChangedModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
VersionChangedModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: VersionChangedModule, declarations: [VersionChangedComponent], imports: [CommonModule,
        MonkeyButtonModule,
        MonkeyIconModule,
        MonkeyInputModule,
        MonkeyModalModule, i1$1.TranslateModule], exports: [VersionChangedComponent] });
VersionChangedModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: VersionChangedModule, imports: [[
            CommonModule,
            MonkeyButtonModule,
            MonkeyIconModule,
            MonkeyInputModule,
            MonkeyModalModule,
            TranslateModule.forChild()
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: VersionChangedModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [VersionChangedComponent],
                    imports: [
                        CommonModule,
                        MonkeyButtonModule,
                        MonkeyIconModule,
                        MonkeyInputModule,
                        MonkeyModalModule,
                        TranslateModule.forChild()
                    ],
                    exports: [VersionChangedComponent]
                }]
        }] });

/* eslint-disable max-classes-per-file */
const moment$1 = moment_;
class DateValidator {
    static do(control) {
        if (!control.parent || !control)
            return null;
        if (control && control.value) {
            const dateFormat = 'MM-DD-YYYY';
            if (!moment$1(moment$1(control.value).format(dateFormat), ['DD/MM/YYYY', 'MM-DD-YYYY', 'YYYY-MM-DD'], true).isValid()) {
                return {
                    invalidDate: true
                };
            }
        }
        return null;
    }
}
class DocumentValidator {
    static do(control) {
        if (!control.parent || !control)
            return null;
        if (control && control.value) {
            if (!MonkeyEcxUtils.isCPFCNPJValid(control.value)) {
                return {
                    invalidCpfCnpj: true
                };
            }
        }
        return null;
    }
}
class DocumentRutValidator {
    static do(control) {
        if (!control.parent || !control)
            return null;
        if (control && control.value) {
            if (!MonkeyEcxUtils.isValidRUT(control.value)) {
                return {
                    invalidRut: true
                };
            }
        }
        return null;
    }
}
class ZipCodeValidator {
    static do(control) {
        if (!control.parent || !control)
            return null;
        if (control && control.value) {
            if (!MonkeyEcxUtils.isValidZipCode(control.value)) {
                return {
                    invalidZipCode: true
                };
            }
        }
        return null;
    }
}
class ComboValidator {
    static do(control) {
        if (!control.parent || !control)
            return null;
        if (control && control.value !== '0')
            return null;
        return {
            invalidCombo: true
        };
    }
}
class isTrueValidator {
    static do(control) {
        if (!control.parent || !control)
            return null;
        if (control && control.value !== false)
            return null;
        return {
            invalidTrue: true
        };
    }
}
class PasswordMatchValidation {
    static do(control) {
        if (!control.parent || !control)
            return null;
        const { parent } = control;
        const password = parent.get('password').value;
        const passwordConfirm = parent.get('passwordConfirm').value;
        if (!password || !passwordConfirm)
            return null;
        if (password === passwordConfirm)
            return null;
        return {
            passwordsNotMatching: true
        };
    }
}
class UrlValidator {
    static do(control) {
        if (!control.parent || !control)
            return null;
        if (control && control.value) {
            if (!MonkeyEcxUtils.isValidUrl(control.value)) {
                return {
                    invalidUrl: true
                };
            }
        }
        return null;
    }
}
class CustomDatesStartValidator {
    static do(control) {
        if (!control.parent || !control)
            return null;
        const { parent } = control;
        const valueStart = parent.get('dateStart').value;
        const valueEnd = parent.get('dateEnd').value;
        let dateStart;
        let dateEnd;
        if (valueStart) {
            dateStart = new Date(valueStart);
        }
        if (valueEnd) {
            dateEnd = new Date(valueEnd);
        }
        if (!dateStart || !dateEnd)
            return null;
        if (dateStart > dateEnd) {
            return {
                dateStartMustBeLessThanAnd: true
            };
        }
        return null;
    }
}
class CustomDatesEndValidator {
    static do(control) {
        if (!control.parent || !control)
            return null;
        const { parent } = control;
        const valueStart = parent.get('dateStart').value;
        const valueEnd = parent.get('dateEnd').value;
        let dateStart;
        let dateEnd;
        if (valueStart) {
            dateStart = new Date(valueStart);
        }
        if (valueEnd) {
            dateEnd = new Date(valueEnd);
        }
        if (!dateEnd || !dateStart)
            return null;
        if (dateEnd < dateStart) {
            return {
                dateEndMustBeGreaterThanStart: true
            };
        }
        return null;
    }
}
class UnlockRegisterBuyerValidator {
    static do(control) {
        if (!control.parent || !control)
            return null;
        if (control && control.value !== '#MONKEYBUYER') {
            return {
                invalidUnlockRegister: true
            };
        }
        return null;
    }
}
class UnlockRegisterSponsorValidator {
    static do(control) {
        if (!control.parent || !control)
            return null;
        if (control && control.value !== '#MONKEYSPONSOR') {
            return {
                invalidUnlockRegister: true
            };
        }
        return null;
    }
}
class DateRangeValidator {
    static do(control) {
        if (!control.parent || !control) {
            return null;
        }
        const dates = control.parent.get('dates').value;
        if (dates &&
            (!MonkeyEcxUtils.persistNullEmptyUndefined(dates.startDate) ||
                !MonkeyEcxUtils.persistNullEmptyUndefined(dates.endDate))) {
            return {
                invalidDateRange: true
            };
        }
        return null;
    }
}

var validateUtils = /*#__PURE__*/Object.freeze({
    __proto__: null,
    DateValidator: DateValidator,
    DocumentValidator: DocumentValidator,
    DocumentRutValidator: DocumentRutValidator,
    ZipCodeValidator: ZipCodeValidator,
    ComboValidator: ComboValidator,
    isTrueValidator: isTrueValidator,
    PasswordMatchValidation: PasswordMatchValidation,
    UrlValidator: UrlValidator,
    CustomDatesStartValidator: CustomDatesStartValidator,
    CustomDatesEndValidator: CustomDatesEndValidator,
    UnlockRegisterBuyerValidator: UnlockRegisterBuyerValidator,
    UnlockRegisterSponsorValidator: UnlockRegisterSponsorValidator,
    DateRangeValidator: DateRangeValidator
});

/* eslint-disable no-unused-vars */
/* eslint-disable no-shadow */
var MonkeyEcxQueueEvents;
(function (MonkeyEcxQueueEvents) {
    MonkeyEcxQueueEvents[MonkeyEcxQueueEvents["OnGoing"] = 0] = "OnGoing";
    MonkeyEcxQueueEvents[MonkeyEcxQueueEvents["Finished"] = 1] = "Finished";
    MonkeyEcxQueueEvents[MonkeyEcxQueueEvents["FinishedWithError"] = 2] = "FinishedWithError";
})(MonkeyEcxQueueEvents || (MonkeyEcxQueueEvents = {}));
var MonkeyEcxDownloadEvents;
(function (MonkeyEcxDownloadEvents) {
    MonkeyEcxDownloadEvents[MonkeyEcxDownloadEvents["OnGoing"] = 0] = "OnGoing";
    MonkeyEcxDownloadEvents[MonkeyEcxDownloadEvents["Finished"] = 1] = "Finished";
    MonkeyEcxDownloadEvents[MonkeyEcxDownloadEvents["FinishedWithError"] = 2] = "FinishedWithError";
})(MonkeyEcxDownloadEvents || (MonkeyEcxDownloadEvents = {}));
var MonkeyEcxUploadEvents;
(function (MonkeyEcxUploadEvents) {
    MonkeyEcxUploadEvents[MonkeyEcxUploadEvents["OnGoing"] = 0] = "OnGoing";
    MonkeyEcxUploadEvents[MonkeyEcxUploadEvents["Finished"] = 1] = "Finished";
    MonkeyEcxUploadEvents[MonkeyEcxUploadEvents["FinishedWithError"] = 2] = "FinishedWithError";
})(MonkeyEcxUploadEvents || (MonkeyEcxUploadEvents = {}));
// TODO pegar do json de config
var ApiEndPointsTokenNotMandatory;
(function (ApiEndPointsTokenNotMandatory) {
    ApiEndPointsTokenNotMandatory["Assets"] = "assets/";
    ApiEndPointsTokenNotMandatory["MonkeyEcx"] = "/monkeyecx";
    ApiEndPointsTokenNotMandatory["ViaCep"] = "viacep.com.br/";
})(ApiEndPointsTokenNotMandatory || (ApiEndPointsTokenNotMandatory = {}));
// TODO pegar do json de config
var ApiEndPointsHeaderNotMandatory;
(function (ApiEndPointsHeaderNotMandatory) {
    ApiEndPointsHeaderNotMandatory["Assets"] = "/assets";
    ApiEndPointsHeaderNotMandatory["PayablesUpload"] = "payables-upload";
    ApiEndPointsHeaderNotMandatory["PictureUser"] = "/user-pictures";
    ApiEndPointsHeaderNotMandatory["Documents"] = "documents/";
    ApiEndPointsHeaderNotMandatory["BuyerTaxFile"] = "/buyer-tax-file";
    ApiEndPointsHeaderNotMandatory["ViaCep"] = "viacep.com.br/";
})(ApiEndPointsHeaderNotMandatory || (ApiEndPointsHeaderNotMandatory = {}));

var statics = /*#__PURE__*/Object.freeze({
    __proto__: null,
    get MonkeyEcxQueueEvents () { return MonkeyEcxQueueEvents; },
    get MonkeyEcxDownloadEvents () { return MonkeyEcxDownloadEvents; },
    get MonkeyEcxUploadEvents () { return MonkeyEcxUploadEvents; },
    get ApiEndPointsTokenNotMandatory () { return ApiEndPointsTokenNotMandatory; },
    get ApiEndPointsHeaderNotMandatory () { return ApiEndPointsHeaderNotMandatory; }
});

function buildQueuePropertys(queue) {
    const params = {
        item: Object.assign(Object.assign({}, queue), { id: MonkeyEcxUtils.getRandomString(40) }),
        status: MonkeyEcxQueueEvents.OnGoing
    };
    return params;
}
function buildDownloadPropertys(name, description, size) {
    const params = {
        item: {
            name,
            description,
            id: `${MonkeyEcxUtils.getRandomString(40)}`,
            size,
            createdAt: new Date()
        },
        status: MonkeyEcxQueueEvents.OnGoing
    };
    return params;
}
function buildUploadPropertys(name, description) {
    const params = {
        item: {
            name,
            description,
            id: `${MonkeyEcxUtils.getRandomString(40)}`
        },
        status: MonkeyEcxUploadEvents.OnGoing
    };
    return params;
}
function hasMonkeyEcxServiceAndHandlingProperties(context) {
    return Object.prototype.hasOwnProperty.call(context, 'monkeyecxService');
}

var decoratorsUtils = /*#__PURE__*/Object.freeze({
    __proto__: null,
    buildQueuePropertys: buildQueuePropertys,
    buildDownloadPropertys: buildDownloadPropertys,
    buildUploadPropertys: buildUploadPropertys,
    hasMonkeyEcxServiceAndHandlingProperties: hasMonkeyEcxServiceAndHandlingProperties
});

const moment = moment_;
const EMAIL_REGEXP = /^[\w-.]+@([\w-]+\.)+[\w-]{1,64}$/;
function isEmptyInputValue(value) {
    return value == null || value.length === 0;
}
function emailValidator(control) {
    if (!control.parent || !control || isEmptyInputValue(control.value)) {
        return null;
    }
    const test = EMAIL_REGEXP.test(control.value);
    if (test)
        return null;
    return {
        email: true
    };
}
function dateRangeValidator(control) {
    if (!control.parent || !control || isEmptyInputValue(control.value)) {
        return null;
    }
    const dates = control.parent.get('dates').value;
    if (dates &&
        (!MonkeyEcxUtils.persistNullEmptyUndefined(dates === null || dates === void 0 ? void 0 : dates.startDate) ||
            !MonkeyEcxUtils.persistNullEmptyUndefined(dates === null || dates === void 0 ? void 0 : dates.endDate))) {
        return {
            dateRange: true
        };
    }
    return null;
}
function registerValidator(control, type) {
    if (!control.parent || !control || isEmptyInputValue(control.value)) {
        return null;
    }
    if (control && control.value !== `#MONKEY${type}`.toUpperCase()) {
        return {
            invalidUnlockRegister: true
        };
    }
    return null;
}
function dateStartEndValidator(control) {
    if (!control.parent || !control) {
        return null;
    }
    const { parent } = control;
    const valueStart = parent.get('dateStart').value;
    const valueEnd = parent.get('dateEnd').value;
    let dateStart;
    let dateEnd;
    if (valueStart) {
        dateStart = new Date(valueStart);
    }
    if (valueEnd) {
        dateEnd = new Date(valueEnd);
    }
    if (!dateEnd || !dateStart)
        return null;
    if (dateStart > dateEnd) {
        return {
            dateStartMustBeLessThanAnd: true
        };
    }
    return null;
}
function urlValidator(control) {
    if (!control.parent || !control || isEmptyInputValue(control.value))
        return null;
    if (!MonkeyEcxUtils.isValidUrl(control.value)) {
        return {
            url: true
        };
    }
    return null;
}
function passwordConfirmValidator(control) {
    if (!control.parent || !control || isEmptyInputValue(control.value))
        return null;
    const { parent } = control;
    const password = parent.get('password').value;
    const passwordConfirm = parent.get('passwordConfirm').value;
    if (!password || !passwordConfirm)
        return null;
    if (password === passwordConfirm)
        return null;
    return {
        passwordsNotMatching: true
    };
}
function trueValidator(control) {
    if (!control.parent || !control)
        return null;
    if (control && control.value !== false)
        return null;
    return {
        invalidTrue: true
    };
}
function comboValidator(control) {
    if (!control.parent || !control)
        return null;
    if (control && control.value !== '0')
        return null;
    return {
        invalidCombo: true
    };
}
function zipCodeValidator(control) {
    if (!control.parent || !control || isEmptyInputValue(control.value))
        return null;
    if (control && control.value) {
        if (!MonkeyEcxUtils.isValidZipCode(control.value)) {
            return {
                invalidZipCode: true
            };
        }
    }
    return null;
}
function documentValidator(control, country) {
    if (!control.parent || !control || isEmptyInputValue(control.value))
        return null;
    if (country === 'BR') {
        if (!MonkeyEcxUtils.isCPFCNPJValid(control.value)) {
            return {
                invalidCpfCnpj: true
            };
        }
    }
    else if (country === 'CL') {
        if (!MonkeyEcxUtils.isValidRUT(control.value)) {
            return {
                invalidCpfCnpj: true
            };
        }
    }
    return null;
}
function dateValidator(control) {
    if (!control.parent || !control || isEmptyInputValue(control.value))
        return null;
    const dateFormat = 'MM-DD-YYYY';
    if (!moment(moment(control.value).format(dateFormat), ['DD/MM/YYYY', 'MM-DD-YYYY', 'YYYY-MM-DD'], true).isValid()) {
        return {
            invalidDate: true
        };
    }
    return null;
}
class Validators {
    static email(control) {
        return emailValidator(control);
    }
    static dateRange(control) {
        return dateRangeValidator(control);
    }
    static unlockSponsorRegister(control) {
        return registerValidator(control, 'sponsor');
    }
    static unlockBuyerRegister(control) {
        return registerValidator(control, 'buyer');
    }
    static dateStartEnd(control) {
        return dateStartEndValidator(control);
    }
    static url(control) {
        return urlValidator(control);
    }
    static passwordConfirm(control) {
        return passwordConfirmValidator(control);
    }
    static true(control) {
        return trueValidator(control);
    }
    static combo(control) {
        return comboValidator(control);
    }
    static zipCode(control) {
        return zipCodeValidator(control);
    }
    static documentBR(control) {
        return documentValidator(control, 'BR');
    }
    static documentCL(control) {
        return documentValidator(control, 'CL');
    }
    static date(control) {
        return dateValidator(control);
    }
}

/* eslint-disable object-curly-newline */

function MonkeyEcxCoreServiceConstructor() {
    return (target) => {
        Object.entries(target.prototype).forEach(([key, value]) => {
            const method = target.prototype[key];
            if (key !== 'constructor') {
                target.prototype[key] = function (...args) {
                    const context = this;
                    if (hasMonkeyEcxServiceAndHandlingProperties(context)) {
                        context.monkeyecxService.monkeyecxHandlingService.clearAll();
                    }
                    const result = method.apply(context, args);
                    return result;
                };
            }
        });
        return target;
    };
}
function MonkeyEcxCoreLog(tp) {
    return function (target, propertyName, propertyDescriptor) {
        const method = propertyDescriptor.value;
        propertyDescriptor.value = function (...args) {
            const params = args
                .map((a) => {
                return JSON.stringify(a);
            })
                .join();
            const result = method.apply(this, args);
            const r = JSON.stringify(result);
            console.log(`Call: ${propertyName}(${params}) => ${r}`);
            return result;
        };
        return propertyDescriptor;
    };
}
function MonkeyEcxCoreClearDecorators() {
    return function (target, propertyName, propertyDescriptor) {
        const method = propertyDescriptor.value;
        propertyDescriptor.value = function (...args) {
            const context = this;
            if (hasMonkeyEcxServiceAndHandlingProperties(context)) {
                context.monkeyecxService.monkeyecxHandlingService.clearAll();
            }
            const result = method.apply(context, args);
            return result;
        };
        return propertyDescriptor;
    };
}
function MonkeyEcxCoreService(params) {
    return function (target, propertyName, propertyDescriptor) {
        const method = propertyDescriptor.value;
        propertyDescriptor.value = function (...args) {
            const context = this;
            if (hasMonkeyEcxServiceAndHandlingProperties(context)) {
                context.monkeyecxService.monkeyecxHandlingService.clearAll();
                context.monkeyecxService.monkeyecxHandlingService.setMonkeyEcxServiceCredentials(params);
            }
            const result = method.apply(context, args);
            return result;
        };
        return propertyDescriptor;
    };
}
function MonkeyEcxCoreServicePaged(params) {
    return function (target, propertyName, propertyDescriptor) {
        const method = propertyDescriptor.value;
        propertyDescriptor.value = function (...args) {
            const context = this;
            if (hasMonkeyEcxServiceAndHandlingProperties(context)) {
                const credentials = context.monkeyecxService.monkeyecxHandlingService.getMonkeyEcxServiceCredentials();
                let requestPaged = null;
                if (credentials) {
                    requestPaged = credentials.requestPaged;
                }
                context.monkeyecxService.monkeyecxHandlingService.clearAll();
                context.monkeyecxService.monkeyecxHandlingService.setMonkeyEcxServiceCredentials(Object.assign(Object.assign({}, params), (requestPaged || null)));
            }
            const result = method.apply(context, args);
            return result;
        };
        return propertyDescriptor;
    };
}
function MonkeyEcxCoreServiceQueue(name, description, params) {
    return function (target, propertyName, propertyDescriptor) {
        const method = propertyDescriptor.value;
        propertyDescriptor.value = function (...args) {
            const context = this;
            if (hasMonkeyEcxServiceAndHandlingProperties(context)) {
                if (MonkeyEcxUtils.persistNullEmptyUndefined(params)) {
                    context.monkeyecxService.monkeyecxHandlingService.clearAll();
                    context.monkeyecxService.monkeyecxHandlingService.setMonkeyEcxServiceCredentials(params);
                }
                context.monkeyecxService.monkeyecxHandlingService.setMonkeyEcxRequestQueue(buildQueuePropertys({
                    name,
                    description
                }));
            }
            const result = method.apply(context, args);
            return result;
        };
        return propertyDescriptor;
    };
}

/* eslint-disable space-before-function-paren */
function MonkeyEcxServiceDownload(name, description, params) {
    return function (target, propertyName, propertyDescriptor) {
        const method = propertyDescriptor.value;
        propertyDescriptor.value = function (...args) {
            const context = this;
            if (hasMonkeyEcxServiceAndHandlingProperties(context)) {
                if (MonkeyUtils.persistNullEmptyUndefined(params)) {
                    context.monkeyecxService.monkeyecxHandlingService.clearAll();
                    context.monkeyecxService.monkeyecxHandlingService.setMonkeyEcxServiceCredentials(params);
                }
                context.monkeyecxService.monkeyecxHandlingService.setMonkeyEcxRequestDownload(Object.assign({}, buildDownloadPropertys(name, description)));
            }
            const result = method.apply(context, args);
            return result;
        };
        return propertyDescriptor;
    };
}

/* eslint-disable space-before-function-paren */
function MonkeyEcxServiceUpload(name, description, params) {
    return function (target, propertyName, propertyDescriptor) {
        const method = propertyDescriptor.value;
        propertyDescriptor.value = function (...args) {
            const context = this;
            if (hasMonkeyEcxServiceAndHandlingProperties(context)) {
                if (MonkeyUtils.persistNullEmptyUndefined(params)) {
                    context.monkeyecxService.monkeyecxHandlingService.clearAll();
                    context.monkeyecxService.monkeyecxHandlingService.setMonkeyEcxServiceCredentials(params);
                }
                context.monkeyecxService.monkeyecxHandlingService.setMonkeyEcxRequestUpload(Object.assign({}, buildUploadPropertys(name, description)));
            }
            const result = method.apply(context, args);
            return result;
        };
        return propertyDescriptor;
    };
}

class MonkeyEcxDragDropDirective {
    constructor() {
        this.onFileDropped = new EventEmitter();
        this.background = '#f5fcff';
        this.opacity = '1';
    }
    onDragOver(evt) {
        evt.preventDefault();
        evt.stopPropagation();
        this.background = '#9ecbec';
        this.opacity = '0.8';
    }
    onDragLeave(evt) {
        evt.preventDefault();
        evt.stopPropagation();
        this.background = '#f5fcff';
        this.opacity = '1';
    }
    ondrop(evt) {
        evt.preventDefault();
        evt.stopPropagation();
        this.background = '#f5fcff';
        this.opacity = '1';
        const { files } = evt.dataTransfer;
        if (files.length > 0) {
            this.onFileDropped.emit(files);
        }
    }
}
MonkeyEcxDragDropDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDragDropDirective, deps: [], target: i0.ɵɵFactoryTarget.Directive });
MonkeyEcxDragDropDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.15", type: MonkeyEcxDragDropDirective, selector: "[monkeyecxDragDrop]", outputs: { onFileDropped: "onFileDropped" }, host: { listeners: { "dragover": "onDragOver($event)", "dragleave": "onDragLeave($event)", "drop": "ondrop($event)" }, properties: { "style.background-color": "this.background", "style.opacity": "this.opacity" } }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDragDropDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[monkeyecxDragDrop]'
                }]
        }], propDecorators: { onFileDropped: [{
                type: Output
            }], background: [{
                type: HostBinding,
                args: ['style.background-color']
            }], opacity: [{
                type: HostBinding,
                args: ['style.opacity']
            }], onDragOver: [{
                type: HostListener,
                args: ['dragover', ['$event']]
            }], onDragLeave: [{
                type: HostListener,
                args: ['dragleave', ['$event']]
            }], ondrop: [{
                type: HostListener,
                args: ['drop', ['$event']]
            }] } });

class MonkeyEcxFormatCurrency {
    constructor(elementRef, injector) {
        this.elementRef = elementRef;
        this.injector = injector;
        this.currencyCode = 'BRL';
        this.currentLocale = 'pt-BR';
        this.el = this.elementRef.nativeElement;
        this.currency = this.injector.get(CurrencyPipe);
        const translateService = this.injector.get(TranslateService);
        translateService.get('MONKEY-CURRENCY-CODE').subscribe((_) => {
            this.currencyCode = _;
            this.currentLocale = translateService.getDefaultLang();
        });
    }
    handle(value) {
        const { currencyCode, currentLocale } = this;
        const newValue = MonkeyEcxUtils.handleOnlyNumbers(value);
        return this.currency.transform(newValue / 100, currencyCode, 'symbol', '', currentLocale);
    }
    ngOnInit() {
        this.el.value = this.handle(this.el.value);
    }
    onInput(value) {
        this.el.value = this.handle(value);
    }
}
MonkeyEcxFormatCurrency.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatCurrency, deps: [{ token: i0.ElementRef }, { token: i0.Injector }], target: i0.ɵɵFactoryTarget.Directive });
MonkeyEcxFormatCurrency.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.15", type: MonkeyEcxFormatCurrency, selector: "[monkeyecxFormatCurrency]", host: { listeners: { "input": "onInput($event.target.value)" } }, providers: [CurrencyPipe], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatCurrency, decorators: [{
            type: Directive,
            args: [{
                    selector: '[monkeyecxFormatCurrency]',
                    providers: [CurrencyPipe]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Injector }]; }, propDecorators: { onInput: [{
                type: HostListener,
                args: ['input', ['$event.target.value']]
            }] } });

class MonkeyEcxFormatUpper {
    constructor(_el, _renderer) {
        this._el = _el;
        this._renderer = _renderer;
        // not to do
    }
    onKeyDown(evt) {
        const value = this._el.nativeElement.value.toUpperCase();
        this._renderer.setProperty(this._el.nativeElement, 'value', value);
        this._onChange(value);
        evt.preventDefault();
    }
    onBlur() {
        this._touched();
    }
    writeValue(value) {
        this._renderer.setProperty(this._el.nativeElement, 'value', value);
    }
    registerOnChange(fn) {
        this._onChange = fn;
    }
    registerOnTouched(fn) {
        this._touched = fn;
    }
    setDisabledState(isDisabled) {
        this._renderer.setProperty(this._el.nativeElement, 'disabled', isDisabled);
    }
}
MonkeyEcxFormatUpper.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatUpper, deps: [{ token: i0.ElementRef, self: true }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive });
MonkeyEcxFormatUpper.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.15", type: MonkeyEcxFormatUpper, selector: "[monkeyecxFormatUpper]", host: { listeners: { "keyup": "onKeyDown($event)", "blur": "onBlur($event)" } }, providers: [
        {
            provide: NG_VALUE_ACCESSOR,
            useExisting: forwardRef(() => {
                // eslint-disable-next-line no-use-before-define
                return MonkeyEcxFormatUpper;
            }),
            multi: true
        }
    ], ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFormatUpper, decorators: [{
            type: Directive,
            args: [{
                    selector: '[monkeyecxFormatUpper]',
                    providers: [
                        {
                            provide: NG_VALUE_ACCESSOR,
                            useExisting: forwardRef(() => {
                                // eslint-disable-next-line no-use-before-define
                                return MonkeyEcxFormatUpper;
                            }),
                            multi: true
                        }
                    ]
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef, decorators: [{
                    type: Self
                }] }, { type: i0.Renderer2 }]; }, propDecorators: { onKeyDown: [{
                type: HostListener,
                args: ['keyup', ['$event']]
            }], onBlur: [{
                type: HostListener,
                args: ['blur', ['$event']]
            }] } });

class MonkeyEcxOnlyAlphaNumericDirective {
    constructor(elementRef) {
        this.elementRef = elementRef;
        // not to do
    }
    onInputChange(event) {
        const initalValue = this.elementRef.nativeElement.value;
        this.elementRef.nativeElement.value = MonkeyEcxUtils.handleOnlyAlphaNumeric(initalValue);
        if (initalValue !== this.elementRef.nativeElement.value) {
            event.stopPropagation();
        }
    }
}
MonkeyEcxOnlyAlphaNumericDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxOnlyAlphaNumericDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
MonkeyEcxOnlyAlphaNumericDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.15", type: MonkeyEcxOnlyAlphaNumericDirective, selector: "[monkeyecxOnlyAlphaNumeric]", host: { listeners: { "input": "onInputChange($event)" } }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxOnlyAlphaNumericDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[monkeyecxOnlyAlphaNumeric]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { onInputChange: [{
                type: HostListener,
                args: ['input', ['$event']]
            }] } });

class MonkeyEcxOnlyNumbersDirective {
    constructor(elementRef) {
        this.elementRef = elementRef;
        // not to do
    }
    onInputChange(event) {
        const initalValue = this.elementRef.nativeElement.value;
        this.elementRef.nativeElement.value = MonkeyEcxUtils.handleOnlyNumbers(initalValue);
        if (initalValue !== this.elementRef.nativeElement.value) {
            event.stopPropagation();
        }
    }
}
MonkeyEcxOnlyNumbersDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxOnlyNumbersDirective, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
MonkeyEcxOnlyNumbersDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.15", type: MonkeyEcxOnlyNumbersDirective, selector: "[monkeyecxOnlyNumbers]", host: { listeners: { "input": "onInputChange($event)" } }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxOnlyNumbersDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[monkeyecxOnlyNumbers]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { onInputChange: [{
                type: HostListener,
                args: ['input', ['$event']]
            }] } });

class MonkeyEcxRequestPagedHandling {
    constructor(_url, _pagedParams) {
        this.url = _url;
        this.pagedParams = _pagedParams || {
            page: {}
        };
    }
    handlePagedValuesFromApi(url) {
        if (url.search('\\?') < 0)
            return url;
        const params = url.substr(url.search('\\?') + 1, url.length);
        url = url.substr(0, url.search('\\?'));
        return `${url}?${new HttpParams({
            fromString: params
        }).delete('size').delete('page').toString()}`;
    }
    getUrlParams(url) {
        const { pagedParams } = this;
        const { number, size } = pagedParams === null || pagedParams === void 0 ? void 0 : pagedParams.page;
        const hasInitialQueryParams = url.search('\\?') > 0;
        return `${!hasInitialQueryParams ? '?' : '&'}page=${number || 0}&size=${size || 20}`;
    }
    getRequestWithPagedParams() {
        const { url } = this;
        const handled = this.handlePagedValuesFromApi(url);
        return `${handled}${this.getUrlParams(handled)}`;
    }
}

class MonkeyEcxCommonsService {
    constructor(monkeyecxService, tokenStorage, otherArgs) {
        this.monkeyecxService = monkeyecxService;
        this.tokenStorage = tokenStorage;
        this.otherArgs = otherArgs;
        this.flagValidator = true;
        this.__requestPaged = null;
        this.__onSearchChanged$ = new BehaviorSubject(null);
        this.__onDataChanged$ = new BehaviorSubject(null);
        this.__onLoadingInProgress$ = new BehaviorSubject(false);
        this.__onDataDeleted$ = new BehaviorSubject(null);
        this.__onErrorChanged$ = new BehaviorSubject(null);
        this.__onGovernmentIdDataChanged$ = new BehaviorSubject(null);
        this.__onZipCodeDataChanged$ = new BehaviorSubject(null);
        this.__oni18nDataChanged$ = new BehaviorSubject(null);
        this.__onDoSearch$ = new BehaviorSubject(null);
        this.__onDoPagination$ = new BehaviorSubject(null);
        this.handleInit();
    }
    handleInit() {
        var _a, _b, _c;
        if (this.tokenStorage) {
            this.__tokenCredentials = this.tokenStorage.getToken();
        }
        if ((_a = this.otherArgs) === null || _a === void 0 ? void 0 : _a.router) {
            const { clearOnChangeRoute } = (_c = (_b = this.otherArgs) === null || _b === void 0 ? void 0 : _b.schedule) === null || _c === void 0 ? void 0 : _c.options;
            this.otherArgs.router.events
                .pipe(filter((event) => {
                return event instanceof NavigationStart;
            }), take(1))
                .subscribe(() => {
                var _a, _b, _c;
                if (this.__schedule && clearOnChangeRoute) {
                    (_c = (_b = (_a = this.otherArgs) === null || _a === void 0 ? void 0 : _a.schedule) === null || _b === void 0 ? void 0 : _b.service) === null || _c === void 0 ? void 0 : _c.removeSchedule(this.__schedule);
                    this.__schedule = null;
                }
            });
        }
    }
    getRole() {
        const { __tokenCredentials } = this;
        if (!__tokenCredentials)
            return '';
        if ((__tokenCredentials === null || __tokenCredentials === void 0 ? void 0 : __tokenCredentials.programAdmin) === 'true') {
            return 'PROGRAM_ADMIN';
        }
        return (__tokenCredentials === null || __tokenCredentials === void 0 ? void 0 : __tokenCredentials.role) || '';
    }
    allowedSecurityAccess(args) {
        if (!args)
            return true;
        const roles = args === null || args === void 0 ? void 0 : args.roles;
        const byExclusion = args === null || args === void 0 ? void 0 : args.byExclusion;
        const found = roles === null || roles === void 0 ? void 0 : roles.indexOf(this.getRole());
        let ret = false;
        if (byExclusion) {
            ret = true;
            if (found > -1) {
                ret = false;
            }
        }
        else {
            ret = false;
            if (found > -1) {
                ret = true;
            }
        }
        if (!roles || roles.length === 0 || this.getRole() === 'PROGRAM_ADMIN') {
            ret = true;
        }
        return ret;
    }
    navigateToErrorPage(statusCode, router) {
        const routes = {
            403: 'forbidden',
            404: 'not-found',
            500: 'service-problems',
            503: 'service-problems'
        };
        if (!router) {
            // eslint-disable-next-line no-console
            console.error('Router must be declared');
        }
        else {
            router.navigate([`/app/pages/${routes[statusCode]}`.toLowerCase()], {
                skipLocationChange: true
            });
        }
    }
    setPage(requestPaged) {
        this.__requestPaged = Object.assign(Object.assign({}, this.__requestPaged), requestPaged);
        return this;
    }
    nextPage() {
        if (!this.__requestPaged)
            return false;
        const { page } = this.__requestPaged;
        const { number, totalPages } = page;
        if (number < totalPages) {
            this.__requestPaged = Object.assign(Object.assign({}, this.__requestPaged), { page: Object.assign(Object.assign({}, page), { number: number + 1 }) });
            return true;
        }
        return false;
    }
    getEmbeddedData(data, field) {
        const { _embedded } = data;
        return _embedded ? _embedded[field] : null;
    }
    getNormalizedUrl(url) {
        const { __requestPaged } = this;
        return new MonkeyEcxRequestPagedHandling(url, __requestPaged).getRequestWithPagedParams();
    }
    clear(clearData) {
        var _a, _b, _c;
        if (clearData) {
            this.__data = null;
            this.__requestPaged = null;
            this.__params = null;
            this.__page = null;
            if (this.__schedule) {
                const { queue } = this.__schedule;
                if (queue) {
                    this.otherArgs.queue.service.removeQueueItem(queue);
                }
                (_c = (_b = (_a = this.otherArgs) === null || _a === void 0 ? void 0 : _a.schedule) === null || _b === void 0 ? void 0 : _b.service) === null || _c === void 0 ? void 0 : _c.removeSchedule(this.__schedule);
                this.__schedule = null;
            }
        }
        this.__error = null;
        this.__handledError = null;
        this.flagValidator = false;
    }
    resolve(route, state, otherArgs) {
        var _a, _b, _c;
        this.__data = null;
        this.__page = null;
        this.__requestPaged = null;
        this.flagValidator = true;
        if (this.tokenStorage) {
            this.__tokenCredentials = this.tokenStorage.getToken();
        }
        if (this.allowedSecurityAccess(otherArgs === null || otherArgs === void 0 ? void 0 : otherArgs.security)) {
            Object.entries(this).forEach(([key, value]) => {
                if (value instanceof BehaviorSubject) {
                    this[key] = new BehaviorSubject(null);
                }
            });
            if (this.__schedule) {
                (_c = (_b = (_a = this.otherArgs) === null || _a === void 0 ? void 0 : _a.schedule) === null || _b === void 0 ? void 0 : _b.service) === null || _c === void 0 ? void 0 : _c.removeSchedule(this.__schedule);
                this.__schedule = null;
            }
            const { __requestPaged } = this;
            if (!__requestPaged) {
                this.setPage({
                    page: {
                        number: 0,
                        size: 10
                    }
                });
            }
            if (otherArgs === null || otherArgs === void 0 ? void 0 : otherArgs.callbackPagination) {
                this.__onDoPagination$.subscribe(() => {
                    if (!this.__onLoadingInProgress$.value) {
                        const hasMorePages = this.setPage({
                            page: Object.assign({}, this.__page)
                        }).nextPage();
                        if (hasMorePages && (otherArgs === null || otherArgs === void 0 ? void 0 : otherArgs.callbackPagination)) {
                            otherArgs.callbackPagination();
                        }
                    }
                });
            }
            if (otherArgs === null || otherArgs === void 0 ? void 0 : otherArgs.translateOptions) {
                const { service, keys } = otherArgs.translateOptions;
                this.geti18n(service, keys);
            }
            if (otherArgs === null || otherArgs === void 0 ? void 0 : otherArgs.feature) {
                const { flag, service } = otherArgs.feature;
                service.onFlags
                    .pipe(takeWhile(() => {
                    return this.flagValidator;
                }))
                    .subscribe((val) => {
                    if (val) {
                        const hasFlag = service.getFlag(flag);
                        if (MonkeyEcxUtils.persistNullEmptyUndefined(hasFlag)) {
                            if (!hasFlag) {
                                this.navigateToErrorPage(404, otherArgs.router);
                                return;
                            }
                        }
                        otherArgs === null || otherArgs === void 0 ? void 0 : otherArgs.callbackMain();
                    }
                });
            }
            else {
                otherArgs === null || otherArgs === void 0 ? void 0 : otherArgs.callbackMain();
            }
        }
        else {
            this.navigateToErrorPage(403, otherArgs.router);
        }
    }
    getHTTPHeaderApplicationPDF() {
        return {
            observe: 'response',
            responseType: 'blob'
        };
    }
    genericMethod(link, data, callback) {
        const { href, type } = link;
        this.monkeyecxService[type.toLowerCase()](`${href}`, data).subscribe((resp) => {
            if (callback)
                callback();
        }, (err) => {
            throwError(err);
        });
    }
    geti18n(translateService, keys) {
        translateService
            .getStreamOnTranslationChange(keys)
            .subscribe((translations) => {
            this.__i18n = translations;
            this.__oni18nDataChanged$.next(null);
        });
    }
}
__decorate([
    MonkeyEcxCoreService({
        requestInProgress: {
            showProgress: true
        }
    })
], MonkeyEcxCommonsService.prototype, "genericMethod", null);

/* eslint-disable max-len */
class MonkeyEcxHandlingService {
    clearAll() {
        this.monkeyecxServiceCredentials = null;
        this.monkeyecxRequestQueue = null;
        this.monkeyecxRequestDownload = null;
        this.monkeyecxRequestUpload = null;
    }
    setMonkeyEcxServiceCredentials(param) {
        this.monkeyecxServiceCredentials = param;
    }
    getMonkeyEcxServiceCredentials() {
        return this.monkeyecxServiceCredentials;
    }
    setMonkeyEcxRequestQueue(queue) {
        this.monkeyecxRequestQueue = queue;
    }
    getMonkeyEcxRequestQueue() {
        return this.monkeyecxRequestQueue;
    }
    setMonkeyEcxRequestDownload(download) {
        this.monkeyecxRequestDownload = download;
    }
    getMonkeyEcxRequestDownload() {
        return this.monkeyecxRequestDownload;
    }
    setMonkeyEcxRequestUpload(upload) {
        this.monkeyecxRequestUpload = upload;
    }
    getMonkeyEcxRequestUpload() {
        return this.monkeyecxRequestUpload;
    }
}
MonkeyEcxHandlingService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHandlingService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxHandlingService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHandlingService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHandlingService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class MonkeyEcxService {
    constructor(http, monkeyecxHandlingService) {
        this.http = http;
        this.monkeyecxHandlingService = monkeyecxHandlingService;
        // not to do
    }
    handlelize(params) {
        if (!params) {
            return params;
        }
        // eslint-disable-next-line no-restricted-syntax
        for (const field of [
            'createdAt',
            'createUserId',
            'updatedAt',
            'lastUserId',
            '_links',
            'governmentIdType',
            'governmentIdMask',
            'screenType',
            'screenTab'
        ]) {
            delete params[field];
        }
        return params;
    }
    get(url, options) {
        return this.http.get(url, options);
    }
    post(url, params, options) {
        return this.http.post(url, params, options);
    }
    put(url, params) {
        return this.http.put(url, this.handlelize(Object.assign({}, params)));
    }
    delete(url, params) {
        return this.http.delete(url, params);
    }
    download(url, options, filename) {
        this.http.get(url, options).subscribe((resp) => {
            const { headers, body } = resp;
            const contentType = headers.get('Content-Type');
            const contentDisposition = headers.get('Content-Disposition');
            if (contentDisposition) {
                filename = contentDisposition
                    .split(';')[1]
                    .split('filename')[1]
                    .split('=')[1]
                    .trim()
                    .replace(new RegExp(/"/g), '');
            }
            const blob = new Blob([body], {
                type: `${contentType}`
            });
            return {
                filename,
                blob
            };
        }, (err) => {
            throwError(err);
        });
    }
    downloadOb(url, options, filename) {
        return this.http.get(url, options).pipe(map((resp) => {
            const { headers, body } = resp;
            const contentType = headers.get('Content-Type');
            const contentDisposition = headers.get('Content-Disposition');
            if (contentDisposition) {
                filename = contentDisposition
                    .split(';')[1]
                    .split('filename')[1]
                    .split('=')[1]
                    .trim()
                    .replace(new RegExp(/"/g), '');
            }
            const blob = new Blob([body], {
                type: `${contentType}`
            });
            return {
                filename,
                blob
            };
        }), catchError((err) => {
            return throwError(err);
        }));
    }
}
MonkeyEcxService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxService, deps: [{ token: i1$4.HttpClient }, { token: MonkeyEcxHandlingService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1$4.HttpClient }, { type: MonkeyEcxHandlingService }]; } });

/* eslint-disable object-curly-newline */
class MonkeyEcxCookieStorageService {
    constructor(cookieService) {
        this.cookieService = cookieService;
        // not to do
    }
    setCookie(name, value) {
        this.removeCookie(name);
        this.cookieService.set(name, value, null, '/', '', true, 'None');
    }
    getCookie(name) {
        return this.cookieService.get(name);
    }
    removeCookie(name) {
        this.cookieService.delete(name, '/');
    }
}
MonkeyEcxCookieStorageService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxCookieStorageService, deps: [{ token: i1$5.CookieService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxCookieStorageService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxCookieStorageService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxCookieStorageService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1$5.CookieService }]; } });

let window$1;
const text = {
    i18n: {
        title: 'We have an quick update for you',
        message: 'Click anywhere here to reload your locale'
    },
    theme: {
        title: 'We have an quick update for you',
        message: 'Click anywhere here to reload your theme'
    }
};
class MonkeyEcxErrorConfigService {
    constructor() {
        // not to do
    }
    enableSupport() {
        window$1.zE('webWidget', 'updateSettings', {
            webWidget: {
                color: {
                    theme: '#0273E8',
                    launcherText: '#fff',
                    header: '#0273E8',
                    button: '#0273E8'
                },
                zIndex: 99,
                offset: {
                    horizontal: '1px',
                    vertical: '20px'
                },
                mobile: {
                    labelVisible: true
                },
                launcher: {
                    mobile: {
                        labelVisible: true
                    }
                }
            }
        });
        window$1.zE('webWidget', 'setLocale', 'en-US');
        window$1.zE('webWidget', 'show');
    }
    apply(type) {
        const { title, message } = text[type];
        const element = document.createElement('div');
        element.id = 'monkeyecx-information';
        const elementImg = document.createElement('img');
        elementImg.width = 128;
        elementImg.src = 'assets/images/monkey.svg';
        elementImg.style.marginBottom = '50px';
        const elementTitle = document.createElement('span');
        elementTitle.id = 'title';
        elementTitle.innerText = title;
        elementTitle.style.marginBottom = '20px';
        const elementMessage = document.createElement('span');
        elementMessage.id = 'message';
        elementMessage.innerText = message;
        elementMessage.style.marginBottom = '20px';
        const elementChat = document.createElement('span');
        elementChat.id = 'message';
        elementChat.innerText =
            "If you're having trouble to update, please use the support icon bellow";
        element.appendChild(elementImg);
        element.appendChild(elementTitle);
        element.appendChild(elementMessage);
        element.appendChild(elementChat);
        element.addEventListener('click', () => {
            document.location.reload();
        });
        document.body.appendChild(element);
        document.body.getElementsByTagName('app-root')[0].remove();
        this.enableSupport();
    }
}
MonkeyEcxErrorConfigService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxErrorConfigService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxErrorConfigService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxErrorConfigService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxErrorConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxi18nConfigService extends MonkeyEcxCommonsService {
    constructor(monkeyecxService, translateService, monkeyecxCookieStorageService, monkeyecxErrorConfigService) {
        super(monkeyecxService);
        this.translateService = translateService;
        this.monkeyecxCookieStorageService = monkeyecxCookieStorageService;
        this.monkeyecxErrorConfigService = monkeyecxErrorConfigService;
        this.translateService.addLangs(['pt-BR', 'en-US']);
        this.translateService.setDefaultLang('pt-BR');
        this.translateService.use('pt-BR');
        this.applyLocal();
    }
    applyLocal() {
        registerLocaleData(localePTBR, 'pt-PT');
    }
    apply(params, environment, change = false) {
        const { monkeyecxService, monkeyecxCookieStorageService, monkeyecxErrorConfigService } = this;
        let { i18n } = params;
        const cookie = monkeyecxCookieStorageService.getCookie('monkey-app-locale');
        if (cookie && !change) {
            i18n = JSON.parse(atob(cookie));
        }
        else {
            monkeyecxCookieStorageService.setCookie('monkey-app-locale', btoa(JSON.stringify(i18n)));
            if (!cookie)
                change = true;
        }
        monkeyecxService.get(`${environment.localAssets}/i18n/${i18n.lang}.json`).subscribe((config) => {
            const { lang, data } = config;
            this.translateService.setTranslation(lang, data, true);
            this.translateService.use(lang);
            if (change)
                document.location.reload();
        }, (err) => {
            console.error(`i18n ${i18n.lang} not found!`);
            monkeyecxErrorConfigService.apply('i18n');
            throwError(err);
        });
    }
}
MonkeyEcxi18nConfigService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxi18nConfigService, deps: [{ token: MonkeyEcxService }, { token: i1$1.TranslateService }, { token: MonkeyEcxCookieStorageService }, { token: MonkeyEcxErrorConfigService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxi18nConfigService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxi18nConfigService, providedIn: 'root' });
__decorate([
    MonkeyEcxCoreService({
        httpResponse: {
            httpCodeIgnore: [404]
        },
        requestInProgress: {
            showProgress: false
        }
    })
], MonkeyEcxi18nConfigService.prototype, "apply", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxi18nConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: MonkeyEcxService }, { type: i1$1.TranslateService }, { type: MonkeyEcxCookieStorageService }, { type: MonkeyEcxErrorConfigService }]; }, propDecorators: { apply: [] } });

class MonkeyEcxLogsConfigService {
    apply(params, configBoostrap, environment, identifyCode) {
        const { program, logs } = params;
        if ((logs === null || logs === void 0 ? void 0 : logs.enabled) && environment.environment !== 'dev') {
            datadogRum.init({
                applicationId: environment === null || environment === void 0 ? void 0 : environment.dataDogApplicationId,
                clientToken: environment === null || environment === void 0 ? void 0 : environment.dataDogClientToken,
                service: program.token,
                site: 'datadoghq.com',
                sampleRate: 100,
                replaySampleRate: 100,
                env: `monkey-front-${identifyCode}-${environment.environment}`,
                version: configBoostrap === null || configBoostrap === void 0 ? void 0 : configBoostrap.version,
                trackInteractions: true,
                trackSessionAcrossSubdomains: true,
                useSecureSessionCookie: true,
                useCrossSiteSessionCookie: true
            });
            datadogRum.startSessionReplayRecording();
        }
    }
}
MonkeyEcxLogsConfigService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxLogsConfigService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxLogsConfigService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxLogsConfigService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxLogsConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });

class MonkeyEcxServiceWorkerConfigService {
    constructor(appRef, updates, modalService) {
        this.appRef = appRef;
        this.updates = updates;
        this.modalService = modalService;
        // not to do
    }
    handleValidation(config) {
        var _a;
        const { updates, modalService } = this;
        (_a = updates === null || updates === void 0 ? void 0 : updates.available) === null || _a === void 0 ? void 0 : _a.subscribe(() => {
            if (!config.showNewVersion || config.maintenance.closed) {
                document.location.reload();
            }
            else {
                modalService.open(VersionChangedComponent, {
                    color: 'theme',
                    size: 'md'
                });
            }
        });
    }
    verify() {
        const { appRef, updates } = this;
        const appIsStable$ = appRef.isStable
            .pipe(first((isStable) => { return isStable === true; }));
        const everyHour$ = interval(1 * 60 * 60 * 1000);
        const everyHourOnceAppIsStable$ = concat(appIsStable$, everyHour$);
        everyHourOnceAppIsStable$.subscribe(() => {
            updates.checkForUpdate();
        });
        updates.checkForUpdate();
    }
    apply(config) {
        this.handleValidation(config);
        this.verify();
    }
}
MonkeyEcxServiceWorkerConfigService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxServiceWorkerConfigService, deps: [{ token: i0.ApplicationRef }, { token: i1$6.SwUpdate }, { token: i1.MonkeyStyleGuideModalService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxServiceWorkerConfigService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxServiceWorkerConfigService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxServiceWorkerConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i0.ApplicationRef }, { type: i1$6.SwUpdate }, { type: i1.MonkeyStyleGuideModalService }]; } });

/* eslint-disable no-console */
class MonkeyEcxSecurityConsoleConfigService extends MonkeyEcxCommonsService {
    constructor(translateService) {
        super();
        this.translateService = translateService;
        this.geti18n(this.translateService, 'SERVICES.WARNING.CONSOLE');
    }
    handleValidation() {
        this.__oni18nDataChanged$.subscribe(() => {
            const { __i18n } = this;
            const title = __i18n === null || __i18n === void 0 ? void 0 : __i18n.TITLE;
            const message = __i18n === null || __i18n === void 0 ? void 0 : __i18n.MESSAGE;
            if (title) {
                console.log(`%c${title}`, 'background: #f2f061; color: #ff0000; font-size: x-large');
                console.log(`%c${message}`, 'font-size: x-large');
                console.log('%c  __  __             _             ______   \n ' +
                    '|  \\/  | ___  _ __ | | _____ _   _\\ \\ \\ \\  \n ' +
                    "| |\\/| |/ _ \\| '_ \\| |/ / _ \\ | | |\\ \\ \\ \\ \n " +
                    '| |  | | (_) | | | |   <  __/ |_| |/ / / / \n ' +
                    '|_|  |_|\\___/|_| |_|_|\\_\\___|\\__, /_/_/_/  \n ' +
                    '                             |___/         \n ' +
                    'Join us: https://monkeyecx.gupy.io', 'background: #1976d2; color: #fff');
            }
        });
    }
    apply() {
        this.handleValidation();
    }
}
MonkeyEcxSecurityConsoleConfigService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxSecurityConsoleConfigService, deps: [{ token: i1$1.TranslateService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxSecurityConsoleConfigService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxSecurityConsoleConfigService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxSecurityConsoleConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1$1.TranslateService }]; } });

class MonkeyEcxMaintenanceConfigService {
    constructor(modalService, router) {
        this.modalService = modalService;
        this.router = router;
        // not to do
    }
    handleValidation(config) {
        if (config.maintenance.closed) {
            localStorage.clear();
            this.router.navigate(['']);
            setTimeout(() => {
                this.modalService.open(ClosedToMaintenanceComponent, {
                    color: 'theme',
                    size: 'md',
                    data: config
                });
            }, 200);
        }
    }
    apply(config) {
        this.handleValidation(config);
    }
}
MonkeyEcxMaintenanceConfigService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxMaintenanceConfigService, deps: [{ token: i1.MonkeyStyleGuideModalService }, { token: i1$3.Router }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxMaintenanceConfigService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxMaintenanceConfigService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxMaintenanceConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.MonkeyStyleGuideModalService }, { type: i1$3.Router }]; } });

class MonkeyEcxFeatureToggleService {
    constructor() {
        this.flagSubject$ = new BehaviorSubject(null);
        // not to do
    }
    getAllFlags() {
        this.flags = this.ldClient.allFlags();
        this.flagSubject$.next(true);
    }
    identify(config, environment) {
        var _a;
        if (config) {
            const email = 'monkey@monkey.exchange';
            const user = {
                email,
                key: `${(_a = config.program) === null || _a === void 0 ? void 0 : _a.token}#${email}`
            };
            if (!this.ldClient) {
                this.ldClient = initialize(environment.launchDarklyClientSideID, user, {
                    streaming: true,
                    disableSyncEventPost: true,
                    sendEvents: false,
                    diagnosticOptOut: true
                });
                this.ldClient.on('change', this.getAllFlags.bind(this));
                this.ldClient.on('ready', this.getAllFlags.bind(this));
            }
            else {
                this.ldClient.identify(user, null, this.getAllFlags);
            }
        }
    }
    apply(configSubject$, environment) {
        if (environment.launchDarklyClientSideID) {
            configSubject$.subscribe((config) => {
                this.identify(config, environment);
            });
        }
        else {
            this.flagSubject$.next(true);
        }
    }
    get onFlags() {
        return this.flagSubject$.asObservable();
    }
    getFlag(flag) {
        var _a;
        const flagValue = (_a = this.flags) === null || _a === void 0 ? void 0 : _a[flag];
        return MonkeyUtils.persistNullEmptyUndefined(flagValue) ? flagValue : null;
    }
}
MonkeyEcxFeatureToggleService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFeatureToggleService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxFeatureToggleService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFeatureToggleService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxFeatureToggleService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxConfigService extends MonkeyEcxCommonsService {
    constructor(monkeyecxService, monkeyecxi18nConfigService, monkeyecxLogsConfigService, monkeyStyleGuideSettingsService, monkeyecxServiceWorkerConfigService, monkeyecxSecurityConsoleConfigService, monkeyecxMaintenanceConfigService, monkeyecxErrorConfigService, monkeyEcxFeatureToggleService) {
        super(monkeyecxService);
        this.monkeyecxi18nConfigService = monkeyecxi18nConfigService;
        this.monkeyecxLogsConfigService = monkeyecxLogsConfigService;
        this.monkeyStyleGuideSettingsService = monkeyStyleGuideSettingsService;
        this.monkeyecxServiceWorkerConfigService = monkeyecxServiceWorkerConfigService;
        this.monkeyecxSecurityConsoleConfigService = monkeyecxSecurityConsoleConfigService;
        this.monkeyecxMaintenanceConfigService = monkeyecxMaintenanceConfigService;
        this.monkeyecxErrorConfigService = monkeyecxErrorConfigService;
        this.monkeyEcxFeatureToggleService = monkeyEcxFeatureToggleService;
        this.configSubject$ = new BehaviorSubject(null);
        this.configBoostrapSubject$ = new BehaviorSubject(null);
    }
    internalValidations(...args) {
        const { monkeyecxServiceWorkerConfigService, monkeyecxSecurityConsoleConfigService, monkeyecxMaintenanceConfigService } = this;
        const configBoostrap = args[0];
        const callback = args[1];
        monkeyecxSecurityConsoleConfigService.apply();
        monkeyecxServiceWorkerConfigService.apply(configBoostrap);
        monkeyecxMaintenanceConfigService.apply(configBoostrap);
        callback(configBoostrap);
    }
    getWhiteLabelSettings(monkeyecxCode, configBoostrap = null, callback, environment, identifyCode) {
        const { monkeyecxService, monkeyecxi18nConfigService, configSubject$, monkeyStyleGuideSettingsService, monkeyecxLogsConfigService, monkeyecxErrorConfigService, monkeyEcxFeatureToggleService, internalValidations } = this;
        const url = `${environment.urlAssets}`;
        monkeyecxService.get(`${url}/${monkeyecxCode.toLowerCase()}/white-label.json`).subscribe((config) => {
            monkeyecxi18nConfigService.apply(config, environment);
            monkeyecxLogsConfigService.apply(config, configBoostrap, environment, identifyCode);
            monkeyEcxFeatureToggleService.apply(configSubject$, environment);
            monkeyStyleGuideSettingsService.boostrap(`${url}/${monkeyecxCode.toLowerCase()}/monkey-style-guide-settings.json`, internalValidations.bind(this, configBoostrap, callback, environment));
            configSubject$.next(config);
        }, (err) => {
            monkeyecxErrorConfigService.apply('theme');
            console.error('Program Configuration not found!');
            throwError(err);
        });
    }
    init(callback, environment, identifyCode, monkeyecxCode) {
        const { monkeyecxService, configBoostrapSubject$, monkeyecxErrorConfigService } = this;
        monkeyecxService
            .get(`${environment.boostrapAssets}?t=${MonkeyUtils.getRandomString(30)}`, {
            observe: 'response'
        })
            .subscribe((resp) => {
            const { headers, body } = resp;
            const monkeyCode = headers.get('monkey-code') || monkeyecxCode;
            if (monkeyCode) {
                this.getWhiteLabelSettings(monkeyCode, body, callback, environment, identifyCode);
                configBoostrapSubject$.next(body);
            }
            else {
                monkeyecxErrorConfigService.apply('theme');
                console.error(`Boostrap ${monkeyCode} Configuration not found!`);
            }
        }, (err) => {
            monkeyecxErrorConfigService.apply('theme');
            console.error('Boostrap Configuration not found!');
            throwError(err);
        });
    }
    config() {
        return this.configSubject$.asObservable();
    }
    boostrapConfig() {
        return this.configBoostrapSubject$.asObservable();
    }
}
MonkeyEcxConfigService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxConfigService, deps: [{ token: MonkeyEcxService }, { token: MonkeyEcxi18nConfigService }, { token: MonkeyEcxLogsConfigService }, { token: i1.MonkeyStyleGuideSettingsService }, { token: MonkeyEcxServiceWorkerConfigService }, { token: MonkeyEcxSecurityConsoleConfigService }, { token: MonkeyEcxMaintenanceConfigService }, { token: MonkeyEcxErrorConfigService }, { token: MonkeyEcxFeatureToggleService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxConfigService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxConfigService, providedIn: 'root' });
__decorate([
    MonkeyEcxCoreService({
        httpResponse: {
            httpCodeIgnore: [404]
        },
        requestInProgress: {
            showProgress: false
        }
    })
], MonkeyEcxConfigService.prototype, "init", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxConfigService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: MonkeyEcxService }, { type: MonkeyEcxi18nConfigService }, { type: MonkeyEcxLogsConfigService }, { type: i1.MonkeyStyleGuideSettingsService }, { type: MonkeyEcxServiceWorkerConfigService }, { type: MonkeyEcxSecurityConsoleConfigService }, { type: MonkeyEcxMaintenanceConfigService }, { type: MonkeyEcxErrorConfigService }, { type: MonkeyEcxFeatureToggleService }]; }, propDecorators: { init: [] } });

class MonkeyEcxTokenStorageService {
    constructor(monkeyecxConfigService) {
        this.monkeyecxConfigService = monkeyecxConfigService;
        this.config = null;
        this.token = {
            username: '',
            program: '',
            accessToken: '',
            refreshToken: '',
            companyId: '',
            governmentId: '',
            companyTypeUrl: '',
            companyType: '',
            programAdmin: false,
            programType: '',
            role: '',
            _clearIgnore: {
                ignore: ['username', 'program']
            }
        };
        this.token$ = new BehaviorSubject(null);
        this.me$ = new BehaviorSubject(null);
        this.monkeyecxConfigService.config().subscribe((_) => {
            this.config = _;
        });
    }
    setAllTokens(token) {
        const { token$ } = this;
        Object.entries(token).forEach(([key, value]) => {
            if (MonkeyEcxUtils.persistNullEmptyUndefined(value)) {
                localStorage.setItem(key, value);
            }
        });
        token$.next(token);
    }
    getAllTokens() {
        const { token } = this;
        const handledToken = Object.assign({}, token);
        Object.entries(token).forEach(([key, value]) => {
            handledToken[key] = localStorage.getItem(key);
        });
        return handledToken;
    }
    setAllMe(me) {
        const { me$ } = this;
        let previousMe = JSON.parse(localStorage.getItem('me'));
        Object.entries(me).forEach(([key, value]) => {
            if (MonkeyEcxUtils.persistNullEmptyUndefined(value)) {
                previousMe = Object.assign(Object.assign({}, previousMe), { [key]: value });
            }
        });
        localStorage.setItem('me', JSON.stringify(previousMe));
        me$.next(previousMe);
    }
    getAllMe() {
        const me = localStorage.getItem('me');
        return JSON.parse(me);
    }
    tokenHasChanged() {
        return this.token$.asObservable();
    }
    meHasChanged() {
        return this.me$.asObservable() || null;
    }
    getToken() {
        return this.getAllTokens();
    }
    getMe() {
        return this.getAllMe();
    }
    setToken(token) {
        this.setAllTokens(token);
    }
    setMe(me) {
        this.setAllMe(me);
    }
    clear(force) {
        const { token } = this;
        try {
            Object.entries(token).forEach(([key, value]) => {
                if (token._clearIgnore.ignore.filter((val) => {
                    return val === key;
                }).length <= 0 ||
                    force === true) {
                    localStorage.removeItem(key);
                }
            });
            localStorage.removeItem('me');
        }
        catch (error) {
            return of(false);
        }
        return of(true);
    }
    /**
     * @param fields (the name of fields you want to clear. ie: ['companyId', 'role', ...])
     */
    clearCredentials(fields = ['companyId', 'governmentId', 'companyType', 'programAdmin', 'role']) {
        fields === null || fields === void 0 ? void 0 : fields.forEach((key) => {
            localStorage.removeItem(key);
        });
    }
}
MonkeyEcxTokenStorageService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxTokenStorageService, deps: [{ token: MonkeyEcxConfigService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxTokenStorageService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxTokenStorageService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxTokenStorageService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: MonkeyEcxConfigService }]; } });

class MonkeyEcxSecurityDirective {
    constructor(elementRef, tokenStorageService, cdr) {
        this.elementRef = elementRef;
        this.tokenStorageService = tokenStorageService;
        this.cdr = cdr;
        this.byExclusion = false;
        // not to do
    }
    getRole() {
        const { tokenCredentials } = this;
        if (!tokenCredentials)
            return '';
        if ((tokenCredentials === null || tokenCredentials === void 0 ? void 0 : tokenCredentials.programAdmin) === 'true') {
            return 'PROGRAM_ADMIN';
        }
        return (tokenCredentials === null || tokenCredentials === void 0 ? void 0 : tokenCredentials.role) || '';
    }
    handleAccess() {
        const { roles, byExclusion } = this;
        let display = 'none';
        const found = roles === null || roles === void 0 ? void 0 : roles.indexOf(this.getRole());
        if (byExclusion) {
            display = 'block';
            if (found > -1) {
                display = 'none';
            }
        }
        else {
            display = 'none';
            if (found > -1) {
                display = 'block';
            }
        }
        if (!roles || roles.length === 0 || (this.getRole() === 'PROGRAM_ADMIN'))
            display = 'block';
        this.elementRef.nativeElement.style.display = display;
        this.cdr.detectChanges();
    }
    ngOnInit() {
        this.elementRef.nativeElement.style.display = 'none';
        this.cdr.detectChanges();
        this.tokenStorageService.tokenHasChanged().subscribe(() => {
            this.tokenCredentials = this.tokenStorageService.getToken();
            this.handleAccess();
        });
        this.tokenCredentials = this.tokenStorageService.getToken();
        this.handleAccess();
    }
}
MonkeyEcxSecurityDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxSecurityDirective, deps: [{ token: i0.ElementRef }, { token: MonkeyEcxTokenStorageService }, { token: i0.ChangeDetectorRef }], target: i0.ɵɵFactoryTarget.Directive });
MonkeyEcxSecurityDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.15", type: MonkeyEcxSecurityDirective, selector: "[monkeyecxSecurity]", inputs: { roles: ["securityRoles", "roles"], byExclusion: ["securityByExclusion", "byExclusion"] }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxSecurityDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[monkeyecxSecurity]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: MonkeyEcxTokenStorageService }, { type: i0.ChangeDetectorRef }]; }, propDecorators: { roles: [{
                type: Input,
                args: ['securityRoles']
            }], byExclusion: [{
                type: Input,
                args: ['securityByExclusion']
            }] } });

class MonkeyEcxTooltipDirective {
    constructor(el, renderer) {
        this.el = el;
        this.renderer = renderer;
        this.enableToShow = true;
        this.offset = 10;
        // not to do
    }
    onMouseEnter() {
        if (!this.tooltip) {
            this.show();
        }
    }
    onMouseLeave() {
        if (this.tooltip) {
            this.hide();
        }
    }
    clickout() {
        if (this.tooltip) {
            this.hide();
        }
    }
    show() {
        if (this.enableToShow) {
            this.create();
            this.setPosition();
            this.renderer.addClass(this.tooltip, 'monkeyecx-tooltip-show');
            setTimeout(() => {
                this.hide();
            }, 5000);
        }
    }
    hide() {
        if (!this.tooltip)
            return;
        this.renderer.removeClass(this.tooltip, 'monkeyecx-tooltip-show');
        this.renderer.removeChild(document.body, this.tooltip);
        this.tooltip = null;
    }
    create() {
        const tooltipElement = document.createElement('div');
        this.tooltip = this.renderer.createElement('span');
        if (this.tooltipTitle) {
            const tooltipTitleElement = document.createElement('span');
            tooltipTitleElement.innerText = `${this.tooltipTitle}`;
            tooltipTitleElement.className = 'monkeyecx-tooltip-title';
            tooltipElement.appendChild(tooltipTitleElement);
        }
        if (this.tooltipText) {
            const tooltipTextElement = document.createElement('span');
            tooltipTextElement.innerText = `${this.tooltipText}`;
            tooltipTextElement.className = 'monkeyecx-tooltip-description';
            tooltipElement.appendChild(tooltipTextElement);
        }
        this.renderer.appendChild(this.tooltip, tooltipElement);
        this.renderer.appendChild(document.body, this.tooltip);
        this.renderer.addClass(this.tooltip, 'monkeyecx-tooltip');
        this.renderer.addClass(this.tooltip, `monkeyecx-tooltip-${this.tooltipPosition}`);
        this.renderer.setStyle(this.tooltip, '-webkit-transition', `opacity ${this.tooltipDelay}ms`);
        this.renderer.setStyle(this.tooltip, '-moz-transition', `opacity ${this.tooltipDelay}ms`);
        this.renderer.setStyle(this.tooltip, '-o-transition', `opacity ${this.tooltipDelay}ms`);
        this.renderer.setStyle(this.tooltip, 'transition', `opacity ${this.tooltipDelay}ms`);
    }
    setPosition() {
        const hostPos = this.el.nativeElement.getBoundingClientRect();
        const tooltipPos = this.tooltip.getBoundingClientRect();
        const scrollPos = window.pageYOffset || document.documentElement.scrollTop || document.body.scrollTop || 0;
        let top;
        let left;
        if (this.tooltipPosition === 'top') {
            top = hostPos.top - tooltipPos.height - this.offset;
            left = hostPos.left + (hostPos.width - tooltipPos.width) / 2;
        }
        if (this.tooltipPosition === 'bottom') {
            top = hostPos.bottom + this.offset;
            left = hostPos.left + (hostPos.width - tooltipPos.width) / 2;
        }
        if (this.tooltipPosition === 'left') {
            top = hostPos.top + (hostPos.height - tooltipPos.height) / 2;
            left = hostPos.left - tooltipPos.width - this.offset;
        }
        if (this.tooltipPosition === 'right') {
            top = hostPos.top + (hostPos.height - tooltipPos.height) / 2;
            left = hostPos.right + this.offset;
        }
        this.renderer.setStyle(this.tooltip, 'top', `${top + scrollPos}px`);
        this.renderer.setStyle(this.tooltip, 'left', `${left}px`);
    }
}
MonkeyEcxTooltipDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxTooltipDirective, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive });
MonkeyEcxTooltipDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.15", type: MonkeyEcxTooltipDirective, selector: "[monkeyecxTooltip]", inputs: { tooltipDelay: "tooltipDelay", tooltipPosition: "tooltipPosition", tooltipText: "tooltipText", tooltipTitle: "tooltipTitle", enableToShow: "enableToShow" }, host: { listeners: { "mouseenter": "onMouseEnter()", "mouseleave": "onMouseLeave()", "click": "clickout()" } }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxTooltipDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[monkeyecxTooltip]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }]; }, propDecorators: { tooltipDelay: [{
                type: Input
            }], tooltipPosition: [{
                type: Input
            }], tooltipText: [{
                type: Input
            }], tooltipTitle: [{
                type: Input
            }], enableToShow: [{
                type: Input
            }], onMouseEnter: [{
                type: HostListener,
                args: ['mouseenter']
            }], onMouseLeave: [{
                type: HostListener,
                args: ['mouseleave']
            }], clickout: [{
                type: HostListener,
                args: ['click']
            }] } });

class MonkeyFeatureDirective {
    constructor(cdr, elementRef, monkeyecxFeatureToggleService) {
        this.cdr = cdr;
        this.elementRef = elementRef;
        this.monkeyecxFeatureToggleService = monkeyecxFeatureToggleService;
        this.unsubscribeAll = new Subject();
        // not to do
    }
    getFeature(feature) {
        const { monkeyecxFeatureToggleService } = this;
        if (!monkeyecxFeatureToggleService) {
            return false;
        }
        return monkeyecxFeatureToggleService.getFlag(feature);
    }
    handleDisplay() {
        const flag = this.getFeature(this.feature);
        let display = 'none';
        if (!MonkeyEcxUtils.persistNullEmptyUndefined(flag)) {
            return;
        }
        if (flag) {
            display = 'block';
        }
        if (display === 'none') {
            this.elementRef.nativeElement.remove();
        }
        this.elementRef.nativeElement.style.display = display;
        this.cdr.detectChanges();
    }
    ngOnDestroy() {
        this.unsubscribeAll.next();
        this.unsubscribeAll.complete();
    }
    ngOnInit() {
        if (!this.feature)
            return;
        this.elementRef.nativeElement.style.display = 'none';
        this.cdr.detectChanges();
        this.monkeyecxFeatureToggleService.onFlags
            .pipe(takeUntil(this.unsubscribeAll))
            .subscribe((val) => {
            if (val) {
                this.handleDisplay();
            }
        });
    }
}
MonkeyFeatureDirective.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyFeatureDirective, deps: [{ token: i0.ChangeDetectorRef }, { token: i0.ElementRef }, { token: MonkeyEcxFeatureToggleService }], target: i0.ɵɵFactoryTarget.Directive });
MonkeyFeatureDirective.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "12.0.0", version: "12.2.15", type: MonkeyFeatureDirective, selector: "[monkeyecxFeature]", inputs: { feature: ["featureName", "feature"] }, ngImport: i0 });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyFeatureDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[monkeyecxFeature]'
                }]
        }], ctorParameters: function () { return [{ type: i0.ChangeDetectorRef }, { type: i0.ElementRef }, { type: MonkeyEcxFeatureToggleService }]; }, propDecorators: { feature: [{
                type: Input,
                args: ['featureName']
            }] } });

class MonkeyEcxDirectivesModule {
}
MonkeyEcxDirectivesModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDirectivesModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MonkeyEcxDirectivesModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDirectivesModule, declarations: [MonkeyEcxDragDropDirective,
        MonkeyEcxFormatCurrency,
        MonkeyFeatureDirective,
        MonkeyEcxFormatUpper,
        MonkeyEcxOnlyAlphaNumericDirective,
        MonkeyEcxOnlyNumbersDirective,
        MonkeyEcxSecurityDirective,
        MonkeyEcxTooltipDirective], exports: [MonkeyEcxDragDropDirective,
        MonkeyEcxFormatCurrency,
        MonkeyFeatureDirective,
        MonkeyEcxFormatUpper,
        MonkeyEcxOnlyAlphaNumericDirective,
        MonkeyEcxOnlyNumbersDirective,
        MonkeyEcxSecurityDirective,
        MonkeyEcxTooltipDirective] });
MonkeyEcxDirectivesModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDirectivesModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDirectivesModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        MonkeyEcxDragDropDirective,
                        MonkeyEcxFormatCurrency,
                        MonkeyFeatureDirective,
                        MonkeyEcxFormatUpper,
                        MonkeyEcxOnlyAlphaNumericDirective,
                        MonkeyEcxOnlyNumbersDirective,
                        MonkeyEcxSecurityDirective,
                        MonkeyEcxTooltipDirective
                    ],
                    exports: [
                        MonkeyEcxDragDropDirective,
                        MonkeyEcxFormatCurrency,
                        MonkeyFeatureDirective,
                        MonkeyEcxFormatUpper,
                        MonkeyEcxOnlyAlphaNumericDirective,
                        MonkeyEcxOnlyNumbersDirective,
                        MonkeyEcxSecurityDirective,
                        MonkeyEcxTooltipDirective
                    ]
                }]
        }] });

/* eslint-disable no-console */
class MonkeyEcxAuthenticationService {
    constructor() {
        this.hadAtLeastOneLogin = () => {
            console.error('hadAtLeastOneLogin needs to be declared!');
            return null;
        };
        this.redirectApp = () => {
            console.error('redirectApp needs to be declared!');
            return null;
        };
        this.redirectLoginWelcomeBack = () => {
            console.error('redirectLoginWelcomeBack needs to be declared!');
            return null;
        };
        this.isAuthorized = () => {
            console.error('isAuthorized needs to be declared!');
            return false;
        };
        this.getRequestWithHeaders = (request) => {
            console.error('getRequestWithHeaders needs to be declared!');
            return null;
        };
        this.getRequestWithHeadersOb = (request) => {
            console.error('getRequestWithHeadersOb needs to be declared!');
            return null;
        };
        this.refreshShouldHappen = (response) => {
            console.error('refreshShouldHappen needs to be declared!');
            return false;
        };
        this.refreshToken = () => {
            console.error('refreshToken needs to be declared!');
            return null;
        };
        // not to do
    }
    init(args) {
        this.hadAtLeastOneLogin = (args === null || args === void 0 ? void 0 : args.hadAtLeastOneLogin) || this.hadAtLeastOneLogin.bind(this);
        this.redirectApp = (args === null || args === void 0 ? void 0 : args.redirectApp) || this.redirectApp.bind(this);
        this.redirectLoginWelcomeBack = (args === null || args === void 0 ? void 0 : args.redirectLoginWelcomeBack) ||
            this.redirectLoginWelcomeBack.bind(this);
        this.isAuthorized = (args === null || args === void 0 ? void 0 : args.isAuthorized) || this.isAuthorized.bind(this);
        this.getRequestWithHeaders = (args === null || args === void 0 ? void 0 : args.getRequestWithHeaders) ||
            this.getRequestWithHeaders.bind(this);
        this.getRequestWithHeadersOb = args === null || args === void 0 ? void 0 : args.getRequestWithHeadersOb.bind(this);
        this.refreshShouldHappen = (args === null || args === void 0 ? void 0 : args.refreshShouldHappen) || this.refreshShouldHappen.bind(this);
        this.refreshToken = (args === null || args === void 0 ? void 0 : args.refreshToken) || this.refreshToken.bind(this);
    }
}
MonkeyEcxAuthenticationService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxAuthenticationService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxAuthenticationService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxAuthenticationService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxAuthenticationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxAuthGuardLogin {
    constructor(monkeyecxAuthenticationService) {
        this.monkeyecxAuthenticationService = monkeyecxAuthenticationService;
        // not to do
    }
    canActivate() {
        if (this.monkeyecxAuthenticationService.isAuthorized()) {
            this.monkeyecxAuthenticationService.redirectApp();
            return false;
        }
        if (this.monkeyecxAuthenticationService.hadAtLeastOneLogin()) {
            this.monkeyecxAuthenticationService.redirectLoginWelcomeBack();
            return false;
        }
        return true;
    }
}
MonkeyEcxAuthGuardLogin.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxAuthGuardLogin, deps: [{ token: MonkeyEcxAuthenticationService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxAuthGuardLogin.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxAuthGuardLogin, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxAuthGuardLogin, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: MonkeyEcxAuthenticationService }]; } });

class MonkeyEcxAuthGuard {
    constructor(monkeyecxAuthenticationService) {
        this.monkeyecxAuthenticationService = monkeyecxAuthenticationService;
        // not to do
    }
    canActivate() {
        const { monkeyecxAuthenticationService } = this;
        if (monkeyecxAuthenticationService.isAuthorized()) {
            return true;
        }
        monkeyecxAuthenticationService.redirectLoginWelcomeBack();
        return false;
    }
}
MonkeyEcxAuthGuard.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxAuthGuard, deps: [{ token: MonkeyEcxAuthenticationService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxAuthGuard.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxAuthGuard, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxAuthGuard, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: MonkeyEcxAuthenticationService }]; } });

class MonkeyEcxHttpErrorHandlingService extends MonkeyEcxCommonsService {
    constructor(monkeyecxService, tokenStorage, monkeyecxAuthenticationService, router, snackbarService, translateService) {
        super(monkeyecxService, tokenStorage);
        this.monkeyecxAuthenticationService = monkeyecxAuthenticationService;
        this.router = router;
        this.snackbarService = snackbarService;
        this.translateService = translateService;
        super.resolve(null, null);
        this.geti18n(this.translateService, 'SERVICES.WARNING');
    }
    isHttpCodeIgnoreMessage(tp, httpCode) {
        var _a, _b;
        if (!MonkeyEcxUtils.persistNullEmptyUndefined(tp) && !(tp === null || tp === void 0 ? void 0 : tp.httpResponse)) {
            return false;
        }
        const found = ((_b = (_a = tp === null || tp === void 0 ? void 0 : tp.httpResponse) === null || _a === void 0 ? void 0 : _a.httpCodeIgnore) === null || _b === void 0 ? void 0 : _b.indexOf(httpCode)) > -1;
        return found;
    }
    isHttpCodeIgnoreRedirect(tp, httpCode) {
        var _a, _b;
        if (!MonkeyEcxUtils.persistNullEmptyUndefined(tp) && !(tp === null || tp === void 0 ? void 0 : tp.httpResponse)) {
            return false;
        }
        const found = ((_b = (_a = tp === null || tp === void 0 ? void 0 : tp.httpResponse) === null || _a === void 0 ? void 0 : _a.httpCodeIgnoreRedirect) === null || _b === void 0 ? void 0 : _b.indexOf(httpCode)) > -1;
        return found;
    }
    getMessageType(status) {
        if (status === 409 || status === 400) {
            return 'warning';
        }
        return 'error';
    }
    showMessage(message, error, mkc) {
        var _a;
        const { snackbarService } = this;
        if (!this.isHttpCodeIgnoreMessage(mkc, error.status)) {
            snackbarService.show({
                title: (_a = this.__i18n) === null || _a === void 0 ? void 0 : _a.TITLE,
                message,
                type: this.getMessageType(error.status),
                duration: 4000,
                horizontalPosition: 'center',
                verticalPosition: 'top'
            });
        }
    }
    handleMessage(error, mkc) {
        var _a;
        // eslint-disable-next-line camelcase
        const { notifications, error_description, message } = error.error;
        let customMessage = '';
        if (message) {
            customMessage = message;
        }
        // eslint-disable-next-line camelcase
        if (error_description) {
            // eslint-disable-next-line camelcase
            customMessage = error_description;
        }
        if (notifications) {
            customMessage = notifications;
        }
        if (!customMessage) {
            if (error.error instanceof Blob) {
                const blob = new Blob([error.error], {
                    type: 'application/json'
                });
                const reader = new FileReader();
                reader.addEventListener('loadend', (e) => {
                    const text = e.target.result;
                    const jsonResp = JSON.parse(text);
                    customMessage = jsonResp.notifications;
                    this.showMessage(customMessage, error, mkc);
                });
                reader.readAsText(blob);
            }
            else {
                this.showMessage((_a = this.__i18n['ERROR-HANDLING']) === null || _a === void 0 ? void 0 : _a.ERROR, error, mkc);
            }
        }
        else {
            this.showMessage(customMessage, error, mkc);
        }
    }
    handleError(error, mkc) {
        const { router } = this;
        const { status } = error;
        const routes = {
            403: 'forbidden',
            500: 'service-problems',
            503: 'service-problems'
        };
        const found = routes[status];
        let timeout = 0;
        if (found && !this.isHttpCodeIgnoreRedirect(mkc, error.status)) {
            const route = `/app/pages/${found}`.toLowerCase();
            timeout = 800;
            router.navigate([route]);
        }
        setTimeout(() => {
            this.handleMessage(error, mkc);
        }, timeout);
    }
    handleErrorRefreshToken(error, mkc) {
        if (error.status === 401 || error.status === 400) {
            NgZone.call(this.monkeyecxAuthenticationService.redirectLoginWelcomeBack());
        }
        else if (!this.isHttpCodeIgnoreMessage(mkc, error.status)) {
            this.handleMessage(error, mkc);
        }
    }
}
MonkeyEcxHttpErrorHandlingService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpErrorHandlingService, deps: [{ token: MonkeyEcxService }, { token: MonkeyEcxTokenStorageService }, { token: MonkeyEcxAuthenticationService }, { token: i1$3.Router }, { token: i1.MonkeyStyleGuideSnackbarService }, { token: i1$1.TranslateService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxHttpErrorHandlingService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpErrorHandlingService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpErrorHandlingService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: MonkeyEcxService }, { type: MonkeyEcxTokenStorageService }, { type: MonkeyEcxAuthenticationService }, { type: i1$3.Router }, { type: i1.MonkeyStyleGuideSnackbarService }, { type: i1$1.TranslateService }]; } });

class MonkeyEcxOthersErrorsHandlingService {
    constructor(modalService) {
        this.modalService = modalService;
        // not to do
    }
    handleError(error) {
        const { modalService } = this;
        const { message } = error;
        if (new RegExp(/Loading chunk [\d]+ failed/).test(message)) {
            modalService.open(VersionChangedComponent, {
                color: 'theme',
                size: 'md'
            });
        }
    }
}
MonkeyEcxOthersErrorsHandlingService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxOthersErrorsHandlingService, deps: [{ token: i1.MonkeyStyleGuideModalService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxOthersErrorsHandlingService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxOthersErrorsHandlingService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxOthersErrorsHandlingService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1.MonkeyStyleGuideModalService }]; } });

class MonkeyEcxErrorHandlingService {
    constructor(injector) {
        this.injector = injector;
        // not to do
    }
    handleError(error, type) {
        const { injector } = this;
        const handlingService = injector.get(MonkeyEcxHandlingService);
        const httpErrorHandlingService = injector.get(MonkeyEcxHttpErrorHandlingService);
        const othersErrorsHandlingService = injector.get(MonkeyEcxOthersErrorsHandlingService);
        if (error instanceof HttpErrorResponse) {
            const sCredentials = handlingService.getMonkeyEcxServiceCredentials();
            if (MonkeyEcxUtils.persistNullEmptyUndefined(type) && type === 'refresh_token') {
                httpErrorHandlingService.handleErrorRefreshToken(error, sCredentials);
            }
            else
                httpErrorHandlingService.handleError(error, sCredentials);
        }
        else {
            othersErrorsHandlingService.handleError(error);
        }
    }
}
MonkeyEcxErrorHandlingService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxErrorHandlingService, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxErrorHandlingService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxErrorHandlingService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxErrorHandlingService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i0.Injector }]; } });

class MonkeyEcxErrorHandlingModule {
    static forRoot() {
        return {
            ngModule: MonkeyEcxErrorHandlingModule,
            providers: [
                {
                    provide: ErrorHandler,
                    useClass: MonkeyEcxErrorHandlingService
                }
            ]
        };
    }
}
MonkeyEcxErrorHandlingModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxErrorHandlingModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MonkeyEcxErrorHandlingModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxErrorHandlingModule, imports: [CommonModule] });
MonkeyEcxErrorHandlingModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxErrorHandlingModule, imports: [[CommonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxErrorHandlingModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule]
                }]
        }] });

class MonkeyEcxHttpConfigErrorInterceptor {
    constructor(monkeyecxAuthenticationService, monkeyecxErrorHandlingService) {
        this.monkeyecxAuthenticationService = monkeyecxAuthenticationService;
        this.monkeyecxErrorHandlingService = monkeyecxErrorHandlingService;
        // no to do
    }
    intercept(request, next) {
        return next.handle(request).pipe(map((event) => {
            return event;
        }), catchError((error) => {
            if (this.monkeyecxAuthenticationService.refreshShouldHappen(error)) {
                return this.monkeyecxAuthenticationService.refreshToken().pipe(take(1), map(() => {
                    return this.monkeyecxAuthenticationService.getRequestWithHeaders(request);
                }), mergeMap((resp) => {
                    return next.handle(resp).pipe(catchError((error) => {
                        this.monkeyecxErrorHandlingService.handleError(error, 'refresh_token');
                        return throwError(null);
                    }));
                }), catchError((error) => {
                    this.monkeyecxErrorHandlingService.handleError(error, 'refresh_token');
                    return throwError(null);
                }));
            }
            return throwError(error);
        }));
    }
}
MonkeyEcxHttpConfigErrorInterceptor.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigErrorInterceptor, deps: [{ token: MonkeyEcxAuthenticationService }, { token: MonkeyEcxErrorHandlingService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxHttpConfigErrorInterceptor.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigErrorInterceptor });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigErrorInterceptor, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: MonkeyEcxAuthenticationService }, { type: MonkeyEcxErrorHandlingService }]; } });

class MonkeyEcxHttpConfigHeaderInterceptor {
    constructor(monkeyecxAuthenticationService, monkeyecxErrorHandlingService) {
        this.monkeyecxAuthenticationService = monkeyecxAuthenticationService;
        this.monkeyecxErrorHandlingService = monkeyecxErrorHandlingService;
        // not to do
    }
    intercept(request, next) {
        return this.monkeyecxAuthenticationService.getRequestWithHeadersOb(request).pipe(take(1), map((event) => {
            return event;
        }), mergeMap((resp) => {
            request = request.clone({
                setHeaders: resp
            });
            return next.handle(request);
        }), catchError((error) => {
            this.monkeyecxErrorHandlingService.handleError(error);
            return throwError(error);
        }));
    }
}
MonkeyEcxHttpConfigHeaderInterceptor.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigHeaderInterceptor, deps: [{ token: MonkeyEcxAuthenticationService }, { token: MonkeyEcxErrorHandlingService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxHttpConfigHeaderInterceptor.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigHeaderInterceptor });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigHeaderInterceptor, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: MonkeyEcxAuthenticationService }, { type: MonkeyEcxErrorHandlingService }]; } });

class MonkeyEcxRequestQueueHandlingService {
    constructor() {
        this.queue = [];
        this.newQueue = new BehaviorSubject(false);
        this.queues$ = new BehaviorSubject([]);
    }
    addToQueue(q) {
        this.queue.push(q);
        this.queues$.next(this.queue);
        this.newQueue.next(true);
    }
    markQueueItemAsFinish(q, status, action) {
        const saved = [...this.queue];
        this.queue = [
            ...saved.map((val) => {
                const valSaved = Object.assign({}, val);
                if (val.status === MonkeyEcxQueueEvents.OnGoing) {
                    if (valSaved.item.id === q.item.id) {
                        return Object.assign(Object.assign({}, valSaved), { status: status || MonkeyEcxQueueEvents.Finished, action });
                    }
                }
                return valSaved;
            })
        ];
        this.queues$.next(this.queue);
    }
    updateQueue(q, progress) {
        const saved = [...this.queue];
        this.queue = [
            ...saved.map((val) => {
                const valSaved = Object.assign({}, val);
                const { total, loaded } = progress;
                const currentPecentage = Math.floor((loaded / total) * 100);
                const totalPercentage = 100;
                if (valSaved.item.id === q.item.id) {
                    return Object.assign(Object.assign({}, valSaved), { progress: {
                            loaded,
                            total,
                            currentPercentage: currentPecentage,
                            totalPercentage
                        } });
                }
                return valSaved;
            })
        ];
        this.queues$.next(this.queue);
    }
    deleteQueue(q) {
        const saved = [...this.queue];
        this.queue = [
            ...saved.map((val) => {
                const valSaved = Object.assign({}, val);
                if (valSaved.item.id === q.item.id) {
                    return null;
                }
                return valSaved;
            })
        ].filter((_) => {
            return _;
        });
        this.queues$.next(this.queue);
    }
    setQueue(q) {
        this.addToQueue(q);
    }
    getQueue() {
        return this.queues$.asObservable();
    }
    finishQueueItem(q, action, status) {
        this.markQueueItemAsFinish(q, status, action);
    }
    removeQueueItem(q) {
        this.deleteQueue(q);
    }
    updateQueueItem(q, progress) {
        this.updateQueue(q, progress);
    }
    hasNewQueue() {
        return this.newQueue.pipe(map((_) => {
            return _;
        }));
    }
}
MonkeyEcxRequestQueueHandlingService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestQueueHandlingService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxRequestQueueHandlingService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestQueueHandlingService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestQueueHandlingService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxRequestQueueModalHandlingService {
    constructor() {
        this.queue = [];
        this.newQueue$ = new BehaviorSubject(false);
        this.allQueueFinished$ = new BehaviorSubject(false);
        this.queues$ = new BehaviorSubject([]);
    }
    addToQueue(q) {
        this.queue.push(q);
        this.queues$.next(this.queue);
        this.newQueue$.next(true);
    }
    markQueueItemAsFinish(q, status, action) {
        const saved = [...this.queue];
        this.queue = [
            ...saved.map((val) => {
                const valSaved = Object.assign({}, val);
                if (val.status === MonkeyEcxQueueEvents.OnGoing) {
                    if (valSaved.item.id === q.item.id) {
                        return Object.assign(Object.assign({}, valSaved), { status: status || MonkeyEcxQueueEvents.Finished, action });
                    }
                }
                return valSaved;
            })
        ];
        this.queues$.next(this.queue);
    }
    updateQueue(q, progress) {
        const saved = [...this.queue];
        this.queue = [
            ...saved.map((val) => {
                const valSaved = Object.assign({}, val);
                const { total, loaded } = progress;
                const currentPecentage = Math.floor((loaded / total) * 100);
                const totalPercentage = 100;
                if (valSaved.item.id === q.item.id) {
                    return Object.assign(Object.assign({}, valSaved), { progress: {
                            loaded,
                            total,
                            currentPercentage: currentPecentage,
                            totalPercentage
                        } });
                }
                return valSaved;
            })
        ];
        this.queues$.next(this.queue);
    }
    deleteQueue(q) {
        const saved = [...this.queue];
        this.queue = [
            ...saved.map((val) => {
                const valSaved = Object.assign({}, val);
                if (valSaved.item.id === q.item.id) {
                    return null;
                }
                return valSaved;
            })
        ].filter((_) => {
            return _;
        });
        this.queues$.next(this.queue);
        if (this.queue.length <= 0) {
            this.allQueueFinished$.next(true);
        }
    }
    setQueue(q) {
        this.addToQueue(q);
    }
    getQueue() {
        return this.queues$.asObservable();
    }
    finishQueueItem(q, action, status) {
        this.markQueueItemAsFinish(q, status, action);
    }
    removeQueueItem(q) {
        this.deleteQueue(q);
    }
    updateQueueItem(q, progress) {
        this.updateQueue(q, progress);
    }
    hasNewQueue() {
        return this.newQueue$.pipe(map((_) => {
            return _;
        }));
    }
    hasAllQueueFinished() {
        return this.allQueueFinished$.pipe(map((_) => {
            return _;
        }));
    }
}
MonkeyEcxRequestQueueModalHandlingService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestQueueModalHandlingService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxRequestQueueModalHandlingService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestQueueModalHandlingService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestQueueModalHandlingService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

/* eslint-disable max-len */
class MonkeyEcxHttpConfigQueueInterceptor {
    constructor(injector, monkeyecxRequestQueueHandlingService) {
        this.injector = injector;
        this.monkeyecxRequestQueueHandlingService = monkeyecxRequestQueueHandlingService;
        // not to do
    }
    intercept(request, next) {
        const { injector, isQueueProperty } = this;
        const monkeyecxHandlingService = injector.get(MonkeyEcxHandlingService);
        const monkeyecxRequestQueue = monkeyecxHandlingService.getMonkeyEcxRequestQueue();
        if (isQueueProperty(monkeyecxRequestQueue)) {
            this.monkeyecxRequestQueueHandlingService.setQueue(monkeyecxRequestQueue);
        }
        return next.handle(request).pipe(finalize(() => {
            if (isQueueProperty(monkeyecxRequestQueue)) {
                this.monkeyecxRequestQueueHandlingService.finishQueueItem(monkeyecxRequestQueue);
            }
        }));
    }
    isQueueProperty(mrq) {
        return (MonkeyEcxUtils.persistNullEmptyUndefined(mrq) &&
            MonkeyEcxUtils.persistNullEmptyUndefined(mrq.item.name));
    }
}
MonkeyEcxHttpConfigQueueInterceptor.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigQueueInterceptor, deps: [{ token: i0.Injector }, { token: MonkeyEcxRequestQueueHandlingService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxHttpConfigQueueInterceptor.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigQueueInterceptor });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigQueueInterceptor, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i0.Injector }, { type: MonkeyEcxRequestQueueHandlingService }]; } });

/* eslint-disable max-len */
class MonkeyEcxHttpConfigLoadingInProgressInterceptor {
    constructor(injector) {
        this.injector = injector;
        // no to do
    }
    intercept(request, next) {
        const { injector, isLoadingInProgressProperty } = this;
        const handlingService = injector.get(MonkeyEcxHandlingService);
        const progressBarService = injector.get(MonkeyEcxProgressBarService);
        const inProgress = handlingService.getMonkeyEcxServiceCredentials()
            ? handlingService.getMonkeyEcxServiceCredentials().requestInProgress
            : null;
        if (isLoadingInProgressProperty(inProgress)) {
            progressBarService.show();
        }
        return next.handle(request).pipe(finalize(() => {
            if (isLoadingInProgressProperty(inProgress)) {
                progressBarService.hide();
            }
        }));
    }
    isLoadingInProgressProperty(mlp) {
        return MonkeyEcxUtils.persistNullEmptyUndefined(mlp) &&
            MonkeyEcxUtils.persistNullEmptyUndefined(mlp.showProgress)
            ? mlp.showProgress
            : true;
    }
}
MonkeyEcxHttpConfigLoadingInProgressInterceptor.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigLoadingInProgressInterceptor, deps: [{ token: i0.Injector }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxHttpConfigLoadingInProgressInterceptor.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigLoadingInProgressInterceptor });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigLoadingInProgressInterceptor, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i0.Injector }]; } });

class MonkeyEcxHttpConfigInterceptorModule {
    static forRoot() {
        return {
            ngModule: MonkeyEcxHttpConfigInterceptorModule,
            providers: [
                {
                    provide: HTTP_INTERCEPTORS,
                    useClass: MonkeyEcxHttpConfigHeaderInterceptor,
                    multi: true
                },
                {
                    provide: HTTP_INTERCEPTORS,
                    useClass: MonkeyEcxHttpConfigErrorInterceptor,
                    multi: true
                },
                {
                    provide: HTTP_INTERCEPTORS,
                    useClass: MonkeyEcxHttpConfigQueueInterceptor,
                    multi: true
                },
                {
                    provide: HTTP_INTERCEPTORS,
                    useClass: MonkeyEcxHttpConfigLoadingInProgressInterceptor,
                    multi: true
                }
            ]
        };
    }
}
MonkeyEcxHttpConfigInterceptorModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigInterceptorModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MonkeyEcxHttpConfigInterceptorModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigInterceptorModule, imports: [CommonModule] });
MonkeyEcxHttpConfigInterceptorModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigInterceptorModule, imports: [[CommonModule]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxHttpConfigInterceptorModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [CommonModule]
                }]
        }] });

class MonkeyEcxModel {
    getAction(type) {
        const { _links } = this;
        if (!_links)
            return null;
        const link = _links[type.toLowerCase()];
        return link;
    }
}

/* eslint-disable indent */
class MonkeyEcxConfigModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('MonkeyEcxConfigModule is already loaded. Import it in the AppModule only!');
        }
    }
    static forRoot() {
        return {
            ngModule: MonkeyEcxConfigModule,
            providers: [MonkeyEcxConfigService]
        };
    }
}
MonkeyEcxConfigModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxConfigModule, deps: [{ token: MonkeyEcxConfigModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule });
MonkeyEcxConfigModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxConfigModule });
MonkeyEcxConfigModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxConfigModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxConfigModule, decorators: [{
            type: NgModule
        }], ctorParameters: function () { return [{ type: MonkeyEcxConfigModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }]; } });

class MonkeyEcxLoggedHandlingService {
    constructor() {
        this.schedules = [];
        // not to do
    }
    destroySchedule() {
        this.schedules.forEach((sch) => {
            clearInterval(sch.interval);
        });
        this.schedules = [];
    }
    addSchedule(sch) {
        this.schedules = sch;
    }
    destroy() {
        this.destroySchedule();
    }
}
MonkeyEcxLoggedHandlingService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxLoggedHandlingService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxLoggedHandlingService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxLoggedHandlingService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxLoggedHandlingService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxRequestDownloadHandlingService {
    constructor() {
        this.download = [];
        this.download$ = new BehaviorSubject([]);
    }
    addTo(q) {
        this.download.push(q);
        this.download$.next(this.download);
    }
    markItemAsFinish(q, status) {
        const saved = [...this.download];
        this.download = [
            ...saved
                .map((val) => {
                if (val.status === MonkeyEcxDownloadEvents.OnGoing) {
                    const valSaved = Object.assign({}, val);
                    if (valSaved.item.id === q.item.id) {
                        return Object.assign(Object.assign({}, valSaved), { status: status || MonkeyEcxDownloadEvents.Finished });
                    }
                    return valSaved;
                }
                return null;
            })
                .filter((_) => {
                return _;
            })
        ];
        this.download = this.download.filter((_) => {
            return _.status === MonkeyEcxDownloadEvents.OnGoing;
        });
        this.download$.next(this.download);
    }
    updateItem(q, loaded, total) {
        const saved = [...this.download];
        this.download = [
            ...saved.map((val) => {
                const valSaved = Object.assign({}, val);
                const currentPecentage = Math.floor((loaded / total) * 100);
                const totalPercentage = 100;
                if (valSaved.item.id === q.item.id) {
                    return Object.assign(Object.assign({}, valSaved), { loaded,
                        total, currentPercentage: currentPecentage, totalPercentage });
                }
                return valSaved;
            })
        ];
        this.download$.next(this.download);
    }
    set(q) {
        this.addTo(q);
    }
    get() {
        return this.download$.asObservable();
    }
    update(q, loaded, total) {
        this.updateItem(q, loaded, total);
    }
    finishItem(q, status) {
        this.markItemAsFinish(q, status);
    }
    hasDownloadOnGoing() {
        const found = this.download.find((_) => {
            return _.status === MonkeyEcxDownloadEvents.OnGoing;
        });
        return MonkeyEcxUtils.persistNullEmptyUndefined(found);
    }
}
MonkeyEcxRequestDownloadHandlingService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestDownloadHandlingService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxRequestDownloadHandlingService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestDownloadHandlingService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestDownloadHandlingService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxRequestDownloadedHandlingService {
    constructor() {
        this.downloaded = [];
        this.downloaded$ = new BehaviorSubject([]);
    }
    addTo(q) {
        this.downloaded.push(q);
        this.downloaded$.next(this.downloaded);
    }
    markItemAsFinish(q, status) {
        const saved = [...this.downloaded];
        this.downloaded = [
            ...saved.map((val) => {
                if (val.status === MonkeyEcxDownloadEvents.OnGoing) {
                    const valSaved = Object.assign({}, val);
                    if (valSaved.item.id === q.item.id) {
                        return Object.assign(Object.assign({}, valSaved), { status: status || MonkeyEcxDownloadEvents.Finished, action: q.action });
                    }
                    return valSaved;
                }
                return val;
            })
        ];
        this.downloaded$.next(this.downloaded);
    }
    set(q) {
        this.addTo(q);
    }
    get() {
        return this.downloaded$.asObservable();
    }
    finishItem(q, status) {
        this.markItemAsFinish(q, status);
    }
    hasDownloadOnGoing() {
        const found = this.downloaded.find((_) => {
            return _.status === MonkeyEcxDownloadEvents.OnGoing;
        });
        return MonkeyEcxUtils.persistNullEmptyUndefined(found);
    }
}
MonkeyEcxRequestDownloadedHandlingService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestDownloadedHandlingService, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxRequestDownloadedHandlingService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestDownloadedHandlingService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestDownloadedHandlingService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return []; } });

class MonkeyEcxDiscoveryParamsService {
    constructor(router) {
        this.router = router;
        // not to do
    }
    getLastChild(route) {
        if (route.firstChild) {
            return this.getLastChild(route.firstChild);
        }
        return route;
    }
    setData(field, value) {
        const { root } = this.router.routerState.snapshot;
        const route = this.getLastChild(root);
        route.data[field] = value;
    }
    getData(field) {
        const { root } = this.router.routerState.snapshot;
        const route = this.getLastChild(root);
        const found = MonkeyEcxUtils.persistNullEmptyUndefined(route) ? route.data[field] : null;
        return found;
    }
    getDataFromCurrentNavigation(field) {
        const navigation = this.router.getCurrentNavigation();
        let state = null;
        if (MonkeyEcxUtils.persistNullEmptyUndefined(navigation)) {
            state = navigation.extras.state;
        }
        return state ? state[field] : null;
    }
    getParam(param) {
        const { root } = this.router.routerState.snapshot;
        const route = this.getLastChild(root);
        let found = MonkeyEcxUtils.persistNullEmptyUndefined(route)
            ? route.paramMap.get(param)
            : '';
        if (!MonkeyEcxUtils.persistNullEmptyUndefined(found))
            found = this.getData(param);
        return found;
    }
}
MonkeyEcxDiscoveryParamsService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDiscoveryParamsService, deps: [{ token: i1$3.Router }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxDiscoveryParamsService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDiscoveryParamsService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxDiscoveryParamsService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: i1$3.Router }]; } });

class MonkeyEcxRequestScheduleService {
    constructor(monkeyecxService, monkeyecxLoggedHandlingService) {
        this.monkeyecxService = monkeyecxService;
        this.monkeyecxLoggedHandlingService = monkeyecxLoggedHandlingService;
        this.schedule = [];
        // not to do
    }
    addToSchedule(q) {
        this.schedule.push(q);
        this.monkeyecxLoggedHandlingService.addSchedule(this.schedule);
    }
    removeFromSchedule(q) {
        clearInterval(q.interval);
        const saved = [...this.schedule];
        this.schedule = [
            ...saved.map((sch) => {
                const savedLocal = Object.assign({}, sch);
                if (sch.id === q.id) {
                    return null;
                }
                return savedLocal;
            })
        ].filter((_) => {
            return _;
        });
        this.monkeyecxLoggedHandlingService.addSchedule(this.schedule);
    }
    removeFromScheduleById(id) {
        const q = this.getScheduleById(id);
        clearInterval(q.interval);
        const saved = [...this.schedule];
        this.schedule = [
            ...saved.map((sch) => {
                const savedLocal = Object.assign({}, sch);
                if (sch.id === q.id) {
                    return null;
                }
                return savedLocal;
            })
        ].filter((_) => {
            return _;
        });
        this.monkeyecxLoggedHandlingService.addSchedule(this.schedule);
    }
    doCall(sch) {
        const { url, method, params, data, action } = sch;
        this.monkeyecxService[method.toLowerCase()](`${url}`, params).subscribe((resp) => {
            action(Object.assign(Object.assign({}, data), resp), sch);
        }, () => {
            this.removeFromSchedule(sch);
        });
    }
    setSchedule(q, delay = 3000) {
        const interval = setInterval(() => {
            this.doCall(Object.assign(Object.assign({}, q), { interval }));
        }, delay);
        const sch = Object.assign(Object.assign({}, q), { id: `${MonkeyEcxUtils.getRandomString(40)}`, interval });
        this.addToSchedule(sch);
        return sch;
    }
    removeSchedule(q) {
        this.removeFromSchedule(q);
    }
    removeScheduleById(id) {
        this.removeFromScheduleById(id);
    }
    getScheduleById(id) {
        const q = this.schedule.find((sch) => {
            return sch.id === id;
        });
        return q;
    }
}
MonkeyEcxRequestScheduleService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestScheduleService, deps: [{ token: MonkeyEcxService }, { token: MonkeyEcxLoggedHandlingService }], target: i0.ɵɵFactoryTarget.Injectable });
MonkeyEcxRequestScheduleService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestScheduleService, providedIn: 'root' });
__decorate([
    MonkeyEcxCoreService({
        httpResponse: {
            httpCodeIgnore: [400, 403, 404, 500, 503]
        },
        requestInProgress: {
            showProgress: false
        }
    })
], MonkeyEcxRequestScheduleService.prototype, "doCall", null);
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyEcxRequestScheduleService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: MonkeyEcxService }, { type: MonkeyEcxLoggedHandlingService }]; }, propDecorators: { doCall: [] } });

/* eslint-disable no-unused-vars */
var OpSearch;
(function (OpSearch) {
    OpSearch["LIKE"] = ":*:value*";
    OpSearch["BETWEEN"] = ":first AND :last";
    OpSearch["OR"] = "OR";
    OpSearch["AND"] = "AND";
    OpSearch["GT"] = ">:value";
    OpSearch["LT"] = "<:value";
    OpSearch["EQUAL"] = "::value";
})(OpSearch || (OpSearch = {}));
class MonkeyEcxSpecificationSearch {
    constructor() {
        // not to do
    }
    handleValue(value) {
        return Object.entries(value).map(([key, value1]) => {
            if (!MonkeyEcxUtils.persistNullEmptyUndefined(value1)) {
                return null;
            }
            if (Array.isArray(value1)) {
                if (key === OpSearch.BETWEEN) {
                    return `${key}`.replace(':first', value1[0]).replace(':last', value1[1]);
                }
            }
            return `${key}`.replace(':value', value1.toString());
        })[0];
    }
    queryVisitor(value) {
        const okay = Object.entries(value).map(([key1, value1]) => {
            if (key1 === OpSearch.OR || key1 === OpSearch.AND) {
                const join = value1
                    .map((_) => {
                    return Object.entries(_).map(([key2, value2]) => {
                        if (value2 instanceof Object) {
                            value2 = this.handleValue(value2);
                        }
                        return this.criteriaParser(key2, value2);
                    })[0];
                })
                    .filter((_) => {
                    return _;
                })
                    .join(` ${key1} `);
                return `${join ? `(${join})` : ''}`;
            }
            if (value1 instanceof Object) {
                value1 = this.handleValue(value1);
            }
            return this.criteriaParser(key1, value1);
        });
        return okay
            .filter((_) => {
            return _;
        })
            .join(' AND ');
    }
    criteriaParser(key, value) {
        if (!MonkeyEcxUtils.persistNullEmptyUndefined(value)) {
            return '';
        }
        if (value instanceof Object) {
            return this.queryVisitor(value);
        }
        return `${key}${value}`;
    }
    build(spec) {
        try {
            return this.queryVisitor(spec);
        }
        catch (e) {
            throw new Error(`MonkeyEcxSpecificationSearch Error ${e}`);
        }
    }
    buildMoreThanOne(field, op = OpSearch.EQUAL) {
        var _a, _b;
        try {
            if (!this[field])
                return [];
            const filters = (_b = (_a = this[field]) === null || _a === void 0 ? void 0 : _a.split(',')) === null || _b === void 0 ? void 0 : _b.map((filter) => {
                if (!filter)
                    return null;
                return {
                    [field]: {
                        [op]: `${filter}`
                    }
                };
            }).filter((val) => { return val; });
            return filters || [];
        }
        catch (e) {
            throw new Error(`MonkeyEcxSpecificationSearch Error ${e}`);
        }
    }
}

class MonkeyFrontCoreModuleModule {
}
MonkeyFrontCoreModuleModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyFrontCoreModuleModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
MonkeyFrontCoreModuleModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyFrontCoreModuleModule, imports: [CommonModule,
        HttpClientModule, i1$1.TranslateModule, MonkeyEcxConfigModule, MonkeyEcxHttpConfigInterceptorModule, MonkeyEcxErrorHandlingModule, MonkeyStyleGuideModule, i1$6.ServiceWorkerModule, ClosedToMaintenanceModule,
        VersionChangedModule] });
MonkeyFrontCoreModuleModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyFrontCoreModuleModule, providers: [
        MonkeyStyleGuideModalService,
        MonkeyStyleGuideSettingsService,
        MonkeyStyleGuideSnackbarService
    ], imports: [[
            CommonModule,
            HttpClientModule,
            TranslateModule.forRoot(),
            MonkeyEcxConfigModule.forRoot(),
            MonkeyEcxHttpConfigInterceptorModule.forRoot(),
            MonkeyEcxErrorHandlingModule.forRoot(),
            MonkeyStyleGuideModule,
            ServiceWorkerModule.register('ngsw-worker.js'),
            ClosedToMaintenanceModule,
            VersionChangedModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.15", ngImport: i0, type: MonkeyFrontCoreModuleModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        HttpClientModule,
                        TranslateModule.forRoot(),
                        MonkeyEcxConfigModule.forRoot(),
                        MonkeyEcxHttpConfigInterceptorModule.forRoot(),
                        MonkeyEcxErrorHandlingModule.forRoot(),
                        MonkeyStyleGuideModule,
                        ServiceWorkerModule.register('ngsw-worker.js'),
                        ClosedToMaintenanceModule,
                        VersionChangedModule
                    ],
                    providers: [
                        MonkeyStyleGuideModalService,
                        MonkeyStyleGuideSettingsService,
                        MonkeyStyleGuideSnackbarService
                    ]
                }]
        }] });

/*
 * Public API Surface of monkey-front-core
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ClosedToMaintenanceComponent, ClosedToMaintenanceModule, decoratorsUtils as DecoratorsUtils, MonkeyEcxAuthGuard, MonkeyEcxAuthGuardLogin, MonkeyEcxAuthenticationService, MonkeyEcxCommonsService, MonkeyEcxConfigModule, MonkeyEcxConfigService, MonkeyEcxCookieStorageService, MonkeyEcxCoreClearDecorators, MonkeyEcxCoreLog, MonkeyEcxCoreService, MonkeyEcxCoreServiceConstructor, MonkeyEcxCoreServicePaged, MonkeyEcxCoreServiceQueue, MonkeyEcxDirectivesModule, MonkeyEcxDiscoveryParamsService, MonkeyEcxDisplayFirstNamePipe, MonkeyEcxDocumentTypePipe, MonkeyEcxDragDropDirective, MonkeyEcxErrorHandlingModule, MonkeyEcxErrorHandlingService, MonkeyEcxFeatureToggleService, MonkeyEcxFormatCurrency, MonkeyEcxFormatCurrencyPipe, MonkeyEcxFormatDateTimelapsePipe, MonkeyEcxFormatDocumentPipe, MonkeyEcxFormatNumber, MonkeyEcxFormatSizePipe, MonkeyEcxFormatUpper, MonkeyEcxFormatValue, MonkeyEcxFormatZipCodePipe, MonkeyEcxHandlingService, MonkeyEcxHttpConfigErrorInterceptor, MonkeyEcxHttpConfigHeaderInterceptor, MonkeyEcxHttpConfigInterceptorModule, MonkeyEcxHttpConfigLoadingInProgressInterceptor, MonkeyEcxHttpConfigQueueInterceptor, MonkeyEcxHttpErrorHandlingService, MonkeyEcxLoggedHandlingService, MonkeyEcxLogsConfigService, MonkeyEcxMaintenanceConfigService, MonkeyEcxModel, MonkeyEcxOnlyAlphaNumericDirective, MonkeyEcxOnlyNumbersDirective, MonkeyEcxOthersErrorsHandlingService, MonkeyEcxPipesModule, MonkeyEcxProgressBarComponent, MonkeyEcxProgressBarModule, MonkeyEcxProgressBarService, MonkeyEcxRequestDownloadHandlingService, MonkeyEcxRequestDownloadedHandlingService, MonkeyEcxRequestPagedHandling, MonkeyEcxRequestQueueHandlingService, MonkeyEcxRequestQueueModalHandlingService, MonkeyEcxRequestScheduleService, MonkeyEcxSecurityConsoleConfigService, MonkeyEcxSecurityDirective, MonkeyEcxService, MonkeyEcxServiceDownload, MonkeyEcxServiceUpload, MonkeyEcxServiceWorkerConfigService, MonkeyEcxSpecificationSearch, MonkeyEcxTextTruncatePipe, MonkeyEcxTokenStorageService, MonkeyEcxTooltipDirective, MonkeyEcxTruncateQtdPipe, MonkeyEcxUtils, MonkeyEcxi18nConfigService, MonkeyFeatureDirective, MonkeyFrontCoreModuleModule, OpSearch, statics as Statics, validateUtils as ValidateUtils, Validators, VersionChangedComponent, VersionChangedModule, comboValidator, dateRangeValidator, dateStartEndValidator, dateValidator, documentValidator, emailValidator, passwordConfirmValidator, registerValidator, trueValidator, urlValidator, zipCodeValidator };
//# sourceMappingURL=monkey-front-core.js.map
